@@ -1,7 +1,33 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 from mobilitydb.time import TimestampSet, Period, PeriodSet
-from mobilitydb.main import TBoolInst, TBoolI, TBoolSeq, TBoolS
+from mobilitydb.main import TBoolInst, TBoolInstSet, TBoolSeq, TBoolSeqSet
 
 
 print("\nConstructors for TBoolInst")
@@ -13,20 +39,20 @@ t = parse('2019-09-08')
 inst = TBoolInst('True', t)
 print(inst)
 
-print("\nConstructors for TBoolI")
-ti = TBoolI('{True@2019-09-08, False@2019-09-09, False@2019-09-10}')
-print(ti)
-ti = TBoolI('True@2019-09-08', 'False@2019-09-09', 'False@2019-09-10')
-print(ti)
-ti = TBoolI(['True@2019-09-08', 'False@2019-09-09', 'False@2019-09-10'])
-print(ti)
+print("\nConstructors for TBoolInstSet")
+ti = TBoolInstSet('{True@2019-09-08, False@2019-09-09, False@2019-09-10}')
+print(tinstset)
+ti = TBoolInstSet('True@2019-09-08', 'False@2019-09-09', 'False@2019-09-10')
+print(tinstset)
+ti = TBoolInstSet(['True@2019-09-08', 'False@2019-09-09', 'False@2019-09-10'])
+print(tinstset)
 t1 = TBoolInst('True@2019-09-08')
 t2 = TBoolInst('False@2019-09-09')
 t3 = TBoolInst('False@2019-09-10')
-ti = TBoolI(t1, t2, t3)
-print(ti)
-ti = TBoolI([t1, t2, t3])
-print(ti)
+ti = TBoolInstSet(t1, t2, t3)
+print(tinstset)
+ti = TBoolInstSet([t1, t2, t3])
+print(tinstset)
 
 print("\nConstructors for TBoolSeq")
 seq = TBoolSeq('[True@2019-09-08, False@2019-09-09, False@2019-09-10]')
@@ -38,14 +64,14 @@ print(seq)
 seq = TBoolSeq([t1, t2, t3], False, True)
 print(seq)
 
-print("\nConstructors for TBoolS")
-ts = TBoolS('{[True@2019-09-08, False@2019-09-09, False@2019-09-10],[False@2019-09-11, True@2019-09-12]}')
+print("\nConstructors for TBoolSeqSet")
+ts = TBoolSeqSet('{[True@2019-09-08, False@2019-09-09, False@2019-09-10],[False@2019-09-11, True@2019-09-12]}')
 print(ts)
-ts = TBoolS(['[True@2019-09-08, False@2019-09-09, False@2019-09-10]', '[False@2019-09-11, True@2019-09-12]'])
+ts = TBoolSeqSet(['[True@2019-09-08, False@2019-09-09, False@2019-09-10]', '[False@2019-09-11, True@2019-09-12]'])
 print(ts)
 seq1 = TBoolSeq('[True@2019-09-08, False@2019-09-09, False@2019-09-10]')
 seq2 = TBoolSeq('[False@2019-09-11, True@2019-09-12]')
-ts = TBoolS([seq1, seq2])
+ts = TBoolSeqSet([seq1, seq2])
 print(ts)
 
 
@@ -61,11 +87,11 @@ print(ti.__class__.__bases__)
 print(seq.__class__.__bases__)
 print(ts.__class__.__bases__)
 
-print("\nduration")
-print(inst.duration())
-print(ti.duration())
-print(seq.duration())
-print(ts.duration())
+print("\ntempSubtype")
+print(inst.tempSubtype())
+print(ti.tempSubtype())
+print(seq.tempSubtype())
+print(ts.tempSubtype())
 
 print("\ninterpolation")
 print(seq.interpolation)
@@ -113,6 +139,12 @@ print(ti.getTime)
 print(seq.getTime)
 print(ts.getTime)
 
+print("\nduration")
+print(inst.duration)
+print(ti.duration)
+print(seq.duration)
+print(ts.duration)
+
 print("\ntimespan")
 print(inst.timespan)
 print(ti.timespan)
@@ -218,12 +250,12 @@ print(ti.intersectsTimestamp(t))
 print(seq.intersectsTimestamp(t))
 print(ts.intersectsTimestamp(t))
 
-print("\nintersectsTimestampset")
+print("\nintersectsTimestampSet")
 tss = TimestampSet('{2019-09-09, 2019-09-10}')
-print(inst.intersectsTimestampset(tss))
-print(ti.intersectsTimestampset(tss))
-print(seq.intersectsTimestampset(tss))
-print(ts.intersectsTimestampset(tss))
+print(inst.intersectsTimestampSet(tss))
+print(ti.intersectsTimestampSet(tss))
+print(seq.intersectsTimestampSet(tss))
+print(ts.intersectsTimestampSet(tss))
 
 print("\nintersectsPeriod")
 p = Period('2019-09-09', '2019-09-10', True, True)
@@ -232,9 +264,9 @@ print(ti.intersectsPeriod(p))
 print(seq.intersectsPeriod(p))
 print(ts.intersectsPeriod(p))
 
-print("\nintersectsPeriodset")
+print("\nintersectsPeriodSet")
 ps = PeriodSet('{[2019-09-09,2019-09-10], [2019-09-11,2019-09-12]}')
-print(inst.intersectsPeriodset(ps))
-print(ti.intersectsPeriodset(ps))
-print(seq.intersectsPeriodset(ps))
-print(ts.intersectsPeriodset(ps))
+print(inst.intersectsPeriodSet(ps))
+print(ti.intersectsPeriodSet(ps))
+print(seq.intersectsPeriodSet(ps))
+print(ts.intersectsPeriodSet(ps))
