@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import asyncio
 from mobilitydb.asyncpg import register
 from mobilitydb.examples.db_connect import asyncpg_connect
@@ -48,10 +74,10 @@ async def run():
         print(len(rows), "record(s) inserted successfully into tbl_tboolinst table")
 
         ######################
-        # TBoolI
+        # TBoolInstSet
         ######################
 
-        select_query = "select * from tbl_tbooli order by k limit 10"
+        select_query = "select * from tbl_tboolinstset order by k limit 10"
 
         print("\n****************************************************************")
         print("Selecting rows from tbl_tbooli table\n")
@@ -59,17 +85,17 @@ async def run():
 
         for row in rows:
             print("key =", row[0])
-            print("tbooli =", row[1])
+            print("tboolinstset =", row[1])
             if not row[1]:
                 print("")
             else:
                 print("startTimestamp =", row[1].startTimestamp, "\n")
 
-        drop_table_query = '''DROP TABLE IF EXISTS tbl_tbooli_temp;'''
+        drop_table_query = '''DROP TABLE IF EXISTS tbl_tboolinstset_temp;'''
         await connection.execute(drop_table_query)
         print("Table deleted successfully in PostgreSQL ")
     
-        create_table_query = '''CREATE TABLE tbl_tbooli_temp
+        create_table_query = '''CREATE TABLE tbl_tboolinstset_temp
             (
               k integer PRIMARY KEY,
               temp tbool
@@ -78,10 +104,10 @@ async def run():
         await connection.execute(create_table_query)
         print("Table created successfully in PostgreSQL ")
     
-        postgres_insert_query = ''' INSERT INTO tbl_tbooli_temp (k, temp) VALUES ($1, $2) '''
+        postgres_insert_query = ''' INSERT INTO tbl_tboolinstset_temp (k, temp) VALUES ($1, $2) '''
         await connection.executemany(postgres_insert_query, rows)
         #count = cursor.rowcount
-        print(len(rows), "record(s) inserted successfully into tbl_tbooli_temp table")
+        print(len(rows), "record(s) inserted successfully into tbl_tboolinstset_temp table")
 
         ######################
         # TBoolSeq
@@ -137,11 +163,11 @@ async def run():
             else:
                 print("startTimestamp =", row[1].startTimestamp, "\n")
     
-        drop_table_query = '''DROP TABLE IF EXISTS tbl_tbools_temp;'''
+        drop_table_query = '''DROP TABLE IF EXISTS tbl_tboolseqset_temp;'''
         await connection.execute(drop_table_query)
         print("Table deleted successfully in PostgreSQL ")
     
-        create_table_query = '''CREATE TABLE tbl_tbools_temp
+        create_table_query = '''CREATE TABLE tbl_tboolseqset_temp
             (
               k integer PRIMARY KEY,
               temp tbool
@@ -150,10 +176,10 @@ async def run():
         await connection.execute(create_table_query)
         print("Table created successfully in PostgreSQL ")
     
-        postgres_insert_query = ''' INSERT INTO tbl_tbools_temp (k, temp) VALUES ($1, $2) '''
+        postgres_insert_query = ''' INSERT INTO tbl_tboolseqset_temp (k, temp) VALUES ($1, $2) '''
         await connection.executemany(postgres_insert_query, rows)
         # count = cursor.rowcount
-        print(len(rows), "record(s) inserted successfully into tbl_tbools_temp table")
+        print(len(rows), "record(s) inserted successfully into tbl_tboolseqset_temp table")
     
         print("\n****************************************************************")
 
