@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import psycopg2
 from mobilitydb.psycopg import register
 from mobilitydb.examples.db_connect import psycopg_connect
@@ -55,10 +81,10 @@ try:
     print(count, "record(s) inserted successfully into tbl_tboolinst_temp table")
 
     ######################
-    # TBoolI
+    # TBoolInstSet
     ######################
 
-    select_query = "select * from tbl_tbooli order by k limit 10"
+    select_query = "select * from tbl_tboolinstset order by k limit 10"
 
     cursor.execute(select_query)
     print("\n****************************************************************")
@@ -67,18 +93,18 @@ try:
 
     for row in rows:
         print("key =", row[0])
-        print("tbooli =", row[1])
+        print("tboolinstset =", row[1])
         if not row[1]:
             print("")
         else:
             print("startTimestamp =", row[1].startTimestamp, "\n")
 
-    drop_table_query = '''DROP TABLE IF EXISTS tbl_tbooli_temp;'''
+    drop_table_query = '''DROP TABLE IF EXISTS tbl_tboolinstset_temp;'''
     cursor.execute(drop_table_query)
     connection.commit()
     print("Table deleted successfully in PostgreSQL ")
 
-    create_table_query = '''CREATE TABLE tbl_tbooli_temp
+    create_table_query = '''CREATE TABLE tbl_tboolinstset_temp
         (
           k integer PRIMARY KEY,
           temp tbool
@@ -88,11 +114,11 @@ try:
     connection.commit()
     print("Table created successfully in PostgreSQL ")
 
-    postgres_insert_query = ''' INSERT INTO tbl_tbooli_temp (k, temp) VALUES (%s, %s) '''
+    postgres_insert_query = ''' INSERT INTO tbl_tboolinstset_temp (k, temp) VALUES (%s, %s) '''
     result = cursor.executemany(postgres_insert_query, rows)
     connection.commit()
     count = cursor.rowcount
-    print(count, "record(s) inserted successfully into tbl_tbooli_temp table")
+    print(count, "record(s) inserted successfully into tbl_tboolinstset_temp table")
 
     ######################
     # TBoolSeq
@@ -138,7 +164,7 @@ try:
     # TBoolS
     ######################
 
-    select_query = "select * from tbl_tbools order by k limit 10"
+    select_query = "select * from tbl_tboolseqset order by k limit 10"
 
     cursor.execute(select_query)
     print("\n****************************************************************")
@@ -153,12 +179,12 @@ try:
         else:
             print("startTimestamp =", row[1].startTimestamp, "\n")
 
-    drop_table_query = '''DROP TABLE IF EXISTS tbl_tbools_temp;'''
+    drop_table_query = '''DROP TABLE IF EXISTS tbl_tboolseqset_temp;'''
     cursor.execute(drop_table_query)
     connection.commit()
     print("Table deleted successfully in PostgreSQL ")
 
-    create_table_query = '''CREATE TABLE tbl_tbools_temp
+    create_table_query = '''CREATE TABLE tbl_tboolseqset_temp
         (
           k integer PRIMARY KEY,
           temp tbool
@@ -168,11 +194,11 @@ try:
     connection.commit()
     print("Table created successfully in PostgreSQL ")
 
-    postgres_insert_query = ''' INSERT INTO tbl_tbools_temp (k, temp) VALUES (%s, %s) '''
+    postgres_insert_query = ''' INSERT INTO tbl_tboolseqset_temp (k, temp) VALUES (%s, %s) '''
     result = cursor.executemany(postgres_insert_query, rows)
     connection.commit()
     count = cursor.rowcount
-    print(count, "record(s) inserted successfully into tbl_tbools_temp table")
+    print(count, "record(s) inserted successfully into tbl_tboolseqset_temp table")
 
     print("\n****************************************************************")
 
