@@ -1,7 +1,33 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 from mobilitydb.time import TimestampSet, Period, PeriodSet
-from mobilitydb.main import TFloat, TFloatInst, TFloatI, TFloatSeq, TFloatS
+from mobilitydb.main import TFloat, TFloatInst, TFloatInstSet, TFloatSeq, TFloatSeqSet
 
 
 print("\nConstructors for TFloatInst")
@@ -13,20 +39,20 @@ t = parse('2019-09-08')
 inst = TFloatInst(10.0, t)
 print(inst)
 
-print("\nConstructors for TFloatI")
-ti = TFloatI('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
-print(ti)
-ti = TFloatI('10@2019-09-08', '20@2019-09-09', '20@2019-09-10')
-print(ti)
-ti = TFloatI(['10@2019-09-08', '20@2019-09-09', '20@2019-09-10'])
-print(ti)
+print("\nConstructors for TFloatInstSet")
+ti = TFloatInstSet('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
+print(tinstset)
+ti = TFloatInstSet('10@2019-09-08', '20@2019-09-09', '20@2019-09-10')
+print(tinstset)
+ti = TFloatInstSet(['10@2019-09-08', '20@2019-09-09', '20@2019-09-10'])
+print(tinstset)
 t1 = TFloatInst('10@2019-09-08')
 t2 = TFloatInst('20@2019-09-09')
 t3 = TFloatInst('20@2019-09-10')
-ti = TFloatI(t1, t2, t3)
-print(ti)
-ti = TFloatI([t1, t2, t3])
-print(ti)
+ti = TFloatInstSet(t1, t2, t3)
+print(tinstset)
+ti = TFloatInstSet([t1, t2, t3])
+print(tinstset)
 
 print("\nConstructors for TFloatSeq")
 seq = TFloatSeq('[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
@@ -38,14 +64,14 @@ print(seq)
 seq = TFloatSeq([t1, t2, t3], False, True)
 print(seq)
 
-print("\nConstructors for TFloatS")
-ts = TFloatS('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[15@2019-09-11, 30@2019-09-12]}')
+print("\nConstructors for TFloatSeqSet")
+ts = TFloatSeqSet('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[15@2019-09-11, 30@2019-09-12]}')
 print(ts)
-ts = TFloatS(['[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]', '[15@2019-09-11, 30@2019-09-12]'])
+ts = TFloatSeqSet(['[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]', '[15@2019-09-11, 30@2019-09-12]'])
 print(ts)
 seq1 = TFloatSeq('[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
 seq2 = TFloatSeq('[15@2019-09-11, 30@2019-09-12]')
-ts = TFloatS([seq1, seq2])
+ts = TFloatSeqSet([seq1, seq2])
 print(ts)
 
 print("\n__class__ ")
@@ -62,15 +88,15 @@ print(ts.__class__.__bases__)
 
 print("\nRepresentation")
 print(repr(inst))
-print(repr(ti))
+print(repr(tinstset))
 print(repr(seq))
 print(repr(ts))
 
-print("\nduration")
-print(inst.duration())
-print(ti.duration())
-print(seq.duration())
-print(ts.duration())
+print("\ntempSubtype")
+print(inst.tempSubtype())
+print(ti.tempSubtype())
+print(seq.tempSubtype())
+print(ts.tempSubtype())
 
 print("\ninterpolation")
 print(seq.interpolation)
@@ -124,6 +150,12 @@ print(ti.getTime)
 print(seq.getTime)
 print(ts.getTime)
 
+print("\nduration")
+print(inst.duration)
+print(ti.duration)
+print(seq.duration)
+print(ts.duration)
+
 print("\ntimespan")
 print(inst.timespan)
 print(ti.timespan)
@@ -229,12 +261,12 @@ print(ti.intersectsTimestamp(t))
 print(seq.intersectsTimestamp(t))
 print(ts.intersectsTimestamp(t))
 
-print("\nintersectsTimestampset")
+print("\nintersectsTimestampSet")
 tss = TimestampSet('{2019-09-09, 2019-09-10}')
-print(inst.intersectsTimestampset(tss))
-print(ti.intersectsTimestampset(tss))
-print(seq.intersectsTimestampset(tss))
-print(ts.intersectsTimestampset(tss))
+print(inst.intersectsTimestampSet(tss))
+print(ti.intersectsTimestampSet(tss))
+print(seq.intersectsTimestampSet(tss))
+print(ts.intersectsTimestampSet(tss))
 
 print("\nintersectsPeriod")
 p = Period('2019-09-09', '2019-09-10', True, True)
@@ -243,14 +275,14 @@ print(ti.intersectsPeriod(p))
 print(seq.intersectsPeriod(p))
 print(ts.intersectsPeriod(p))
 
-print("\nintersectsPeriodset")
+print("\nintersectsPeriodSet")
 ps = PeriodSet('{[2019-09-09,2019-09-10], [2019-09-11,2019-09-12]}')
-print(inst.intersectsPeriodset(ps))
-print(ti.intersectsPeriodset(ps))
-print(seq.intersectsPeriodset(ps))
-print(ts.intersectsPeriodset(ps))
+print(inst.intersectsPeriodSet(ps))
+print(ti.intersectsPeriodSet(ps))
+print(seq.intersectsPeriodSet(ps))
+print(ts.intersectsPeriodSet(ps))
 
-print("\nequality for TemporalInst")
+print("\nequality for TInstant")
 inst1 = TFloatInst('1@2019-09-09')
 inst2 = TFloatInst('1.0@2019-09-09 00:00:00')
 inst3 = TFloatInst('1.1@2019-09-09')
@@ -259,14 +291,14 @@ print(inst1 == inst2)
 print(inst1 == inst3)
 print(inst1 == inst4)
 
-print("\nequality for TemporalI")
-ti1 = TFloatI('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
-ti2 = TFloatI('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
-ti3 = TFloatI('{10@2019-09-08, 20@2019-09-10}')
+print("\nequality for TInstantSet")
+ti1 = TFloatInstSet('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
+ti2 = TFloatInstSet('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
+ti3 = TFloatInstSet('{10@2019-09-08, 20@2019-09-10}')
 print(ti1 == ti2)
 print(ti1 == ti3)
 
-print("\nequality for TemporalSeq")
+print("\nequality for TSequence")
 seq1 = TFloatSeq('[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
 seq2 = TFloatSeq('[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
 seq3 = TFloatSeq('[10.1@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
@@ -279,25 +311,25 @@ print(seq1 == seq4)
 print(seq1 == seq5)
 print(seq1 == seq6)
 
-print("\nequality for TemporalS")
-ts1 = TFloatS('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11, 20@2019-09-12]}')
-ts2 = TFloatS('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11, 20@2019-09-12]}')
-ts3 = TFloatS('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11]}')
-ts4 = TFloatS('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11, 20@2019-09-12]}', interp='Stepwise')
+print("\nequality for TSequenceSet")
+ts1 = TFloatSeqSet('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11, 20@2019-09-12]}')
+ts2 = TFloatSeqSet('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11, 20@2019-09-12]}')
+ts3 = TFloatSeqSet('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11]}')
+ts4 = TFloatSeqSet('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[10@2019-09-11, 20@2019-09-12]}', interp='Stepwise')
 print(ts1 == ts2)
 print(ts1 == ts3)
 print(ts1 == ts4)
 
 print("*** Manual ***")
-p = TFloatI('{10.0@2019-09-01 00:00:00+01, 20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01}')
+p = TFloatInstSet('{10.0@2019-09-01 00:00:00+01, 20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01}')
 print(p)
-p = TFloatI('10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01')
+p = TFloatInstSet('10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01')
 print(p)
-p = TFloatI(TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01'))
+p = TFloatInstSet(TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01'))
 print(p)
-p = TFloatI(['10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01'])
+p = TFloatInstSet(['10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01'])
 print(p)
-p = TFloatI([TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01')])
+p = TFloatInstSet([TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01')])
 print(p)
 
 print("*** Manual ***")
@@ -315,19 +347,19 @@ p = TFloatSeq([TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-
 print(p)
 
 print("*** Manual ***")
-p = TFloatS('{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
+p = TFloatSeqSet('{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
 print(p)
-p = TFloatS('Interp=Stepwise;{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
+p = TFloatSeqSet('Interp=Stepwise;{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
 print(p)
-p = TFloatS(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'])
+p = TFloatSeqSet(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'])
 print(p)
-p = TFloatS(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Linear')
+p = TFloatSeqSet(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Linear')
 print(p)
-p = TFloatS(['Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Stepwise')
+p = TFloatSeqSet(['Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Stepwise')
 print(p)
-p = TFloatS([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')])
+p = TFloatSeqSet([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')])
 print(p)
-p = TFloatS([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'),  TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Linear')
+p = TFloatSeqSet([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'),  TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Linear')
 print(p)
-p = TFloatS([TFloatSeq('Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Stepwise')
+p = TFloatSeqSet([TFloatSeq('Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Stepwise')
 print(p)
