@@ -1,8 +1,34 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 from postgis import Point, MultiPoint, LineString, MultiLineString, GeometryCollection
 from mobilitydb.time import TimestampSet, Period, PeriodSet
-from mobilitydb.main.tpoint import TGeomPointInst, TGeomPointI, TGeomPointSeq, TGeomPointS
+from mobilitydb.main.tpoint import TGeomPointInst, TGeomPointInstSet, TGeomPointSeq, TGeomPointSeqSet
 
 
 print("\nConstructors for TGeomPointInst")
@@ -15,20 +41,18 @@ t = parse('2019-09-08')
 inst = TGeomPointInst(p, t)
 print(inst)
 
-print("\nConstructors for TGeomPointI")
-ti = TGeomPointI('{Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10}')
-print(ti)
-ti = TGeomPointI('Point(10 10)@2019-09-08', 'Point(20 20)@2019-09-09', 'Point(20 20)@2019-09-10')
-print(ti)
-ti = TGeomPointI(['Point(10 10)@2019-09-08', 'Point(20 20)@2019-09-09', 'Point(20 20)@2019-09-10'])
-print(ti)
+print("\nConstructors for TGeomPointInstSet")
+ti = TGeomPointInstSet('{Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10}')
+print(tinstset)
+ti = TGeomPointInstSet(['Point(10 10)@2019-09-08', 'Point(20 20)@2019-09-09', 'Point(20 20)@2019-09-10'])
+print(tinstset)
 t1 = TGeomPointInst('Point(10 10)@2019-09-08')
 t2 = TGeomPointInst('Point(20 20)@2019-09-09')
 t3 = TGeomPointInst('Point(20 20)@2019-09-10')
-ti = TGeomPointI(t1, t2, t3)
-print(ti)
-ti = TGeomPointI([t1, t2, t3])
-print(ti)
+ti = TGeomPointInstSet([t1, t2, t3])
+print(tinstset)
+ti = TGeomPointInstSet([t1, t2, t3], srid=4326)
+print(tinstset)
 
 print("\nConstructors for TGeomPointSeq")
 seq = TGeomPointSeq('[Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10]')
@@ -37,17 +61,17 @@ seq = TGeomPointSeq(['Point(10 10)@2019-09-08', 'Point(20 20)@2019-09-09', 'Poin
 print(seq)
 seq = TGeomPointSeq([t1, t2, t3])
 print(seq)
-seq = TGeomPointSeq([t1, t2, t3], False, True)
+seq = TGeomPointSeq([t1, t2, t3], False, True, srid=4326)
 print(seq)
 
-print("\nConstructors for TGeomPointS")
-ts = TGeomPointS('{[Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10],[Point(15 15)@2019-09-11, Point(30 30)@2019-09-12]}')
+print("\nConstructors for TGeomPointSeqSet")
+ts = TGeomPointSeqSet('{[Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10],[Point(15 15)@2019-09-11, Point(30 30)@2019-09-12]}')
 print(ts)
-ts = TGeomPointS(['[Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10]', '[Point(15 15)@2019-09-11, Point(30 30)@2019-09-12]'])
+ts = TGeomPointSeqSet(['[Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10]', '[Point(15 15)@2019-09-11, Point(30 30)@2019-09-12]'])
 print(ts)
 seq1 = TGeomPointSeq('[Point(10 10)@2019-09-08, Point(20 20)@2019-09-09, Point(20 20)@2019-09-10]')
 seq2 = TGeomPointSeq('[Point(15 15)@2019-09-11, Point(30 30)@2019-09-12]')
-ts = TGeomPointS([seq1, seq2])
+ts = TGeomPointSeqSet([seq1, seq2])
 print(ts)
 
 print("\n__class__ ")
@@ -62,11 +86,11 @@ print(ti.__class__.__bases__)
 print(seq.__class__.__bases__)
 print(ts.__class__.__bases__)
 
-print("\nduration")
-print(inst.duration())
-print(ti.duration())
-print(seq.duration())
-print(ts.duration())
+print("\ntempSubtype")
+print(inst.tempSubtype())
+print(ti.tempSubtype())
+print(seq.tempSubtype())
+print(ts.tempSubtype())
 
 print("\ninterpolation")
 print(seq.interpolation)
@@ -102,6 +126,12 @@ print(ti.getTime)
 print(seq.getTime)
 print(ts.getTime)
 
+print("\nduration")
+print(inst.duration)
+print(ti.duration)
+print(seq.duration)
+print(ts.duration)
+
 print("\ntimespan")
 print(inst.timespan)
 print(ti.timespan)
@@ -207,12 +237,12 @@ print(ti.intersectsTimestamp(t))
 print(seq.intersectsTimestamp(t))
 print(ts.intersectsTimestamp(t))
 
-print("\nintersectsTimestampset")
+print("\nintersectsTimestampSet")
 tss = TimestampSet('{2019-09-09, 2019-09-10}')
-print(inst.intersectsTimestampset(tss))
-print(ti.intersectsTimestampset(tss))
-print(seq.intersectsTimestampset(tss))
-print(ts.intersectsTimestampset(tss))
+print(inst.intersectsTimestampSet(tss))
+print(ti.intersectsTimestampSet(tss))
+print(seq.intersectsTimestampSet(tss))
+print(ts.intersectsTimestampSet(tss))
 
 print("\nintersectsPeriod")
 p = Period('2019-09-09', '2019-09-10', True, True)
@@ -221,12 +251,12 @@ print(ti.intersectsPeriod(p))
 print(seq.intersectsPeriod(p))
 print(ts.intersectsPeriod(p))
 
-print("\nintersectsPeriodset")
+print("\nintersectsPeriodSet")
 ps = PeriodSet('{[2019-09-09,2019-09-10], [2019-09-11,2019-09-12]}')
-print(inst.intersectsPeriodset(ps))
-print(ti.intersectsPeriodset(ps))
-print(seq.intersectsPeriodset(ps))
-print(ts.intersectsPeriodset(ps))
+print(inst.intersectsPeriodSet(ps))
+print(ti.intersectsPeriodSet(ps))
+print(seq.intersectsPeriodSet(ps))
+print(ts.intersectsPeriodSet(ps))
 
 print("\nsrid")
 print(inst.srid)
