@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 from mobilitydb.time import TimestampSet, Period, PeriodSet
@@ -27,8 +53,8 @@ var1 = var.lower_inc
 print("lower_inc:", var1)
 var1 = var.upper_inc
 print("upper_inc:", var1)
-var1 = var.timespan
-print("timespan:", var1)
+var1 = var.duration
+print("duration:", var1)
 var1 = var.shift(timedelta(days=1))
 print("shift:", var1)
 
@@ -68,6 +94,8 @@ print("Constructor list of datetimes:", var)
 # var = TimestampSet(t1, t2, t3, t4)
 
 # Accessor functions
+var1 = var.timespan
+print("timespan:", var1)
 var1 = var.period
 print("period:", var1)
 var1 = var.numTimestamps
@@ -115,6 +143,8 @@ print("Constructor list of periods:", var)
 # var = PeriodSet(p1, p2, p3, p4)
 
 # Accessor functions
+var1 = var.duration
+print("duration:", var1)
 var1 = var.timespan
 print("timespan:", var1)
 var1 = var.period
