@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import psycopg2
 from mobilitydb.psycopg import register
 from mobilitydb.examples.db_connect import psycopg_connect
@@ -31,7 +57,7 @@ try:
         if not row[1]:
             print("")
         else:
-            print("timespan =", row[1].timespan, "\n")
+            print("duration =", row[1].duration, "\n")
 
     drop_table_query = "DROP TABLE IF EXISTS tbl_timestampset_temp;"
     cursor.execute(drop_table_query)
@@ -70,7 +96,7 @@ try:
         if not row[1]:
             print("")
         else:
-            print("timespan =", row[1].timespan, "\n")
+            print("duration =", row[1].duration, "\n")
 
     drop_table_query = "DROP TABLE IF EXISTS tbl_period_temp;"
     cursor.execute(drop_table_query)
@@ -109,8 +135,7 @@ try:
         if not row[1]:
             print("")
         else:
-            print("timespan =", row[1].timespan, "\n")
-
+            print("duration =", row[1].duration, "\n")
 
     drop_table_query = "DROP TABLE IF EXISTS tbl_periodset_temp;"
     cursor.execute(drop_table_query)
