@@ -1,8 +1,34 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 from spans.types import intrange
 from mobilitydb.time import TimestampSet, Period, PeriodSet
-from mobilitydb.main import TIntInst, TIntI, TIntSeq, TIntS
+from mobilitydb.main import TIntInst, TIntInstSet, TIntSeq, TIntSeqSet
 
 
 print("\nConstructors for TFloatInst")
@@ -14,20 +40,20 @@ t = parse('2019-09-08')
 inst = TIntInst(10, t)
 print(inst)
 
-print("\nConstructors for TIntI")
-ti = TIntI('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
-print(ti)
-ti = TIntI('10@2019-09-08', '20@2019-09-09', '20@2019-09-10')
-print(ti)
-ti = TIntI(['10@2019-09-08', '20@2019-09-09', '20@2019-09-10'])
-print(ti)
+print("\nConstructors for TIntInstSet")
+ti = TIntInstSet('{10@2019-09-08, 20@2019-09-09, 20@2019-09-10}')
+print(tinstset)
+ti = TIntInstSet('10@2019-09-08', '20@2019-09-09', '20@2019-09-10')
+print(tinstset)
+ti = TIntInstSet(['10@2019-09-08', '20@2019-09-09', '20@2019-09-10'])
+print(tinstset)
 t1 = TIntInst('10@2019-09-08')
 t2 = TIntInst('20@2019-09-09')
 t3 = TIntInst('20@2019-09-10')
-ti = TIntI(t1, t2, t3)
-print(ti)
-ti = TIntI([t1, t2, t3])
-print(ti)
+ti = TIntInstSet(t1, t2, t3)
+print(tinstset)
+ti = TIntInstSet([t1, t2, t3])
+print(tinstset)
 
 print("\nConstructors for TIntSeq")
 seq = TIntSeq('[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
@@ -39,14 +65,14 @@ print(seq)
 seq = TIntSeq([t1, t2, t3], False, True)
 print(seq)
 
-print("\nConstructors for TIntS")
-ts = TIntS('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[15@2019-09-11, 30@2019-09-12]}')
+print("\nConstructors for TIntSeqSet")
+ts = TIntSeqSet('{[10@2019-09-08, 20@2019-09-09, 20@2019-09-10],[15@2019-09-11, 30@2019-09-12]}')
 print(ts)
-ts = TIntS(['[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]', '[15@2019-09-11, 30@2019-09-12]'])
+ts = TIntSeqSet(['[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]', '[15@2019-09-11, 30@2019-09-12]'])
 print(ts)
 seq1 = TIntSeq('[10@2019-09-08, 20@2019-09-09, 20@2019-09-10]')
 seq2 = TIntSeq('[15@2019-09-11, 30@2019-09-12]')
-ts = TIntS([seq1, seq2])
+ts = TIntSeqSet([seq1, seq2])
 print(ts)
 
 print("\n__class__ ")
@@ -61,11 +87,11 @@ print(ti.__class__.__bases__)
 print(seq.__class__.__bases__)
 print(ts.__class__.__bases__)
 
-print("\nduration")
-print(inst.duration())
-print(ti.duration())
-print(seq.duration())
-print(ts.duration())
+print("\ntempSubtype")
+print(inst.tempSubtype())
+print(ti.tempSubtype())
+print(seq.tempSubtype())
+print(ts.tempSubtype())
 
 print("\ninterpolation")
 print(seq.interpolation)
@@ -119,6 +145,12 @@ print(ti.getTime)
 print(seq.getTime)
 print(ts.getTime)
 
+print("\nduration")
+print(inst.duration)
+print(ti.duration)
+print(seq.duration)
+print(ts.duration)
+
 print("\ntimespan")
 print(inst.timespan)
 print(ti.timespan)
@@ -224,12 +256,12 @@ print(ti.intersectsTimestamp(t))
 print(seq.intersectsTimestamp(t))
 print(ts.intersectsTimestamp(t))
 
-print("\nintersectsTimestampset")
+print("\nintersectsTimestampSet")
 tss = TimestampSet('{2019-09-09, 2019-09-10}')
-print(inst.intersectsTimestampset(tss))
-print(ti.intersectsTimestampset(tss))
-print(seq.intersectsTimestampset(tss))
-print(ts.intersectsTimestampset(tss))
+print(inst.intersectsTimestampSet(tss))
+print(ti.intersectsTimestampSet(tss))
+print(seq.intersectsTimestampSet(tss))
+print(ts.intersectsTimestampSet(tss))
 
 print("\nintersectsPeriod")
 p = Period('2019-09-09', '2019-09-10', True, True)
@@ -238,12 +270,12 @@ print(ti.intersectsPeriod(p))
 print(seq.intersectsPeriod(p))
 print(ts.intersectsPeriod(p))
 
-print("\nintersectsPeriodset")
+print("\nintersectsPeriodSet")
 ps = PeriodSet('{[2019-09-09,2019-09-10], [2019-09-11,2019-09-12]}')
-print(inst.intersectsPeriodset(ps))
-print(ti.intersectsPeriodset(ps))
-print(seq.intersectsPeriodset(ps))
-print(ts.intersectsPeriodset(ps))
+print(inst.intersectsPeriodSet(ps))
+print(ti.intersectsPeriodSet(ps))
+print(seq.intersectsPeriodSet(ps))
+print(ts.intersectsPeriodSet(ps))
 
 """
 f = TInt('1@2000-01-01')
