@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import psycopg2
 from mobilitydb.psycopg import register
 from mobilitydb.examples.db_connect import psycopg_connect
@@ -73,12 +99,12 @@ try:
         else:
             print("startTimestamp =", row[1].startTimestamp, "\n")
 
-        drop_table_query = '''DROP TABLE IF EXISTS tbl_tinti_temp;'''
+        drop_table_query = '''DROP TABLE IF EXISTS tbl_tintinstset_temp;'''
         cursor.execute(drop_table_query)
         connection.commit()
         print("Table deleted successfully in PostgreSQL ")
 
-        create_table_query = '''CREATE TABLE tbl_tinti_temp
+        create_table_query = '''CREATE TABLE tbl_tintinstset_temp
             (
               k integer PRIMARY KEY,
               temp tint
@@ -88,11 +114,11 @@ try:
         connection.commit()
         print("Table created successfully in PostgreSQL ")
 
-        postgres_insert_query = ''' INSERT INTO tbl_tinti_temp (k, temp) VALUES (%s, %s) '''
+        postgres_insert_query = ''' INSERT INTO tbl_tintinstset_temp (k, temp) VALUES (%s, %s) '''
         result = cursor.executemany(postgres_insert_query, rows)
         connection.commit()
         count = cursor.rowcount
-        print(count, "record(s) inserted successfully into tbl_tinti_temp table")
+        print(count, "record(s) inserted successfully into tbl_tintinstset_temp table")
 
     ######################
     # TIntSeq
@@ -153,12 +179,12 @@ try:
         else:
             print("startTimestamp =", row[1].startTimestamp, "\n")
 
-    drop_table_query = '''DROP TABLE IF EXISTS tbl_tints_temp;'''
+    drop_table_query = '''DROP TABLE IF EXISTS tbl_tintseqset_temp;'''
     cursor.execute(drop_table_query)
     connection.commit()
     print("Table deleted successfully in PostgreSQL ")
 
-    create_table_query = '''CREATE TABLE tbl_tints_temp
+    create_table_query = '''CREATE TABLE tbl_tintseqset_temp
         (
           k integer PRIMARY KEY,
           temp tint
@@ -168,11 +194,11 @@ try:
     connection.commit()
     print("Table created successfully in PostgreSQL ")
 
-    postgres_insert_query = ''' INSERT INTO tbl_tints_temp (k, temp) VALUES (%s, %s) '''
+    postgres_insert_query = ''' INSERT INTO tbl_tintseqset_temp (k, temp) VALUES (%s, %s) '''
     result = cursor.executemany(postgres_insert_query, rows)
     connection.commit()
     count = cursor.rowcount
-    print(count, "record(s) inserted successfully into tbl_tints_temp table")
+    print(count, "record(s) inserted successfully into tbl_tintseqset_temp table")
 
     print("\n****************************************************************")
 
