@@ -1,7 +1,33 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 from mobilitydb.time import TimestampSet, Period, PeriodSet
-from mobilitydb.main import TTextInst, TTextI, TTextSeq, TTextS
+from mobilitydb.main import TTextInst, TTextInstSet, TTextSeq, TTextSeqSet
 
 print("\nConstructors for TTextInst")
 inst = TTextInst('A@2019-09-08')
@@ -12,20 +38,20 @@ t = parse('2019-09-08')
 inst = TTextInst('A', t)
 print(inst)
 
-print("\nConstructors for TText")
-ti = TTextI('{A@2019-09-08, B@2019-09-09, B@2019-09-10}')
-print(ti)
-ti = TTextI('A@2019-09-08', 'B@2019-09-09', 'B@2019-09-10')
-print(ti)
-ti = TTextI(['A@2019-09-08', 'B@2019-09-09', 'B@2019-09-10'])
-print(ti)
+print("\nConstructors for TTextInstSet")
+ti = TTextInstSet('{A@2019-09-08, B@2019-09-09, B@2019-09-10}')
+print(tinstset)
+ti = TTextInstSet('A@2019-09-08', 'B@2019-09-09', 'B@2019-09-10')
+print(tinstset)
+ti = TTextInstSet(['A@2019-09-08', 'B@2019-09-09', 'B@2019-09-10'])
+print(tinstset)
 t1 = TTextInst('A@2019-09-08')
 t2 = TTextInst('B@2019-09-09')
 t3 = TTextInst('B@2019-09-10')
-ti = TTextI(t1, t2, t3)
-print(ti)
-ti = TTextI([t1, t2, t3])
-print(ti)
+ti = TTextInstSet(t1, t2, t3)
+print(tinstset)
+ti = TTextInstSet([t1, t2, t3])
+print(tinstset)
 
 print("\nConstructors for TTextSeq")
 seq = TTextSeq('[A@2019-09-08, B@2019-09-09, B@2019-09-10]')
@@ -37,14 +63,14 @@ print(seq)
 seq = TTextSeq([t1, t2, t3], False, True)
 print(seq)
 
-print("\nConstructors for TTextS")
-ts = TTextS('{[A@2019-09-08, B@2019-09-09, B@2019-09-10],[B@2019-09-11, C@2019-09-12]}')
+print("\nConstructors for TTextSeqSet")
+ts = TTextSeqSet('{[A@2019-09-08, B@2019-09-09, B@2019-09-10],[B@2019-09-11, C@2019-09-12]}')
 print(ts)
-ts = TTextS(['[A@2019-09-08, B@2019-09-09, B@2019-09-10]', '[B@2019-09-11, C@2019-09-12]'])
+ts = TTextSeqSet(['[A@2019-09-08, B@2019-09-09, B@2019-09-10]', '[B@2019-09-11, C@2019-09-12]'])
 print(ts)
 seq1 = TTextSeq('[A@2019-09-08, B@2019-09-09, B@2019-09-10]')
 seq2 = TTextSeq('[B@2019-09-11, C@2019-09-12]')
-ts = TTextS([seq1, seq2])
+ts = TTextSeqSet([seq1, seq2])
 print(ts)
 
 print("\n__class__ ")
@@ -59,11 +85,11 @@ print(ti.__class__.__bases__)
 print(seq.__class__.__bases__)
 print(ts.__class__.__bases__)
 
-print("\nduration")
-print(inst.duration())
-print(ti.duration())
-print(seq.duration())
-print(ts.duration())
+print("\ntempSubtype")
+print(inst.tempSubtype())
+print(ti.tempSubtype())
+print(seq.tempSubtype())
+print(ts.tempSubtype())
 
 print("\ninterpolation")
 print(seq.interpolation)
@@ -111,6 +137,12 @@ print(ti.getTime)
 print(seq.getTime)
 print(ts.getTime)
 
+print("\nduration")
+print(inst.duration)
+print(ti.duration)
+print(seq.duration)
+print(ts.duration)
+
 print("\ntimespan")
 print(inst.timespan)
 print(ti.timespan)
@@ -216,12 +248,12 @@ print(ti.intersectsTimestamp(t))
 print(seq.intersectsTimestamp(t))
 print(ts.intersectsTimestamp(t))
 
-print("\nintersectsTimestampset")
+print("\nintersectsTimestampSet")
 tss = TimestampSet('{2019-09-09, 2019-09-10}')
-print(inst.intersectsTimestampset(tss))
-print(ti.intersectsTimestampset(tss))
-print(seq.intersectsTimestampset(tss))
-print(ts.intersectsTimestampset(tss))
+print(inst.intersectsTimestampSet(tss))
+print(ti.intersectsTimestampSet(tss))
+print(seq.intersectsTimestampSet(tss))
+print(ts.intersectsTimestampSet(tss))
 
 print("\nintersectsPeriod")
 p = Period('2019-09-09', '2019-09-10', True, True)
@@ -230,9 +262,9 @@ print(ti.intersectsPeriod(p))
 print(seq.intersectsPeriod(p))
 print(ts.intersectsPeriod(p))
 
-print("\nintersectsPeriodset")
+print("\nintersectsPeriodSet")
 ps = PeriodSet('{[2019-09-09,2019-09-10], [2019-09-11,2019-09-12]}')
-print(inst.intersectsPeriodset(ps))
-print(ti.intersectsPeriodset(ps))
-print(seq.intersectsPeriodset(ps))
-print(ts.intersectsPeriodset(ps))
+print(inst.intersectsPeriodSet(ps))
+print(ti.intersectsPeriodSet(ps))
+print(seq.intersectsPeriodSet(ps))
+print(ts.intersectsPeriodSet(ps))
