@@ -1,15 +1,44 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from parsec import *
 from datetime import datetime
 from dateutil.parser import parse
-from mobilitydb.temporal import Temporal, TemporalInst, TemporalI, TemporalSeq, TemporalS
+from mobilitydb.temporal import Temporal, TInstant, TInstantSet, TSequence, TSequenceSet
 from mobilitydb.temporal.temporal_parser import parse_temporalinst
 
 
 class TBool(Temporal):
     """
-    Abstract class for representing temporal Booleans of any duration.
+    Abstract class for representing temporal Booleans of any subtype.
     """
 
+    BaseClass = bool
+    BaseClassDiscrete = True
+
     @staticmethod
     def read_from_cursor(value, cursor=None):
         if not value:
@@ -20,21 +49,21 @@ class TBool(Temporal):
             return TBoolSeq(value)
         elif value[0] == '{':
             if value[1] == '[' or value[1] == '(':
-                return TBoolS(value)
+                return TBoolSeqSet(value)
             else:
-                return TBoolI(value)
+                return TBoolInstSet(value)
         raise Exception("ERROR: Could not parse temporal boolean value")
 
     @staticmethod
     def write(value):
         if not isinstance(value, TBool):
-            raise ValueError('TBool value must subclass TBool class')
+            raise ValueError('Value must be an instance of a subclass of TBool')
         return value.__str__().strip("'")
 
 
-class TBoolInst(TemporalInst, TBool):
+class TBoolInst(TInstant, TBool):
     """
-    Class for representing temporal Booleans of instant duration.
+    Class for representing temporal Booleans of instant subtype.
 
     ``TBoolInst`` objects can be created with a single argument of type string
     as in MobilityDB.
@@ -56,7 +85,6 @@ class TBoolInst(TemporalInst, TBool):
     and eval('False') == False. Furthermore eval('false') gives an error
     """
     def __init__(self, value, time=None):
-        TemporalInst.BaseClass = bool
         if time is None:
             # Constructor with a single argument of type string
             if isinstance(value, str):
@@ -83,34 +111,34 @@ class TBoolInst(TemporalInst, TBool):
         self._time = parse(time) if isinstance(time, str) else time
 
 
-class TBoolI(TemporalI, TBool):
+class TBoolInstSet(TInstantSet, TBool):
     """
-    Class for representing temporal Booleans of instant set duration.
+    Class for representing temporal Booleans of instant set subtype.
 
-    ``TBoolI`` objects can be created with a single argument of type string
+    ``TBoolInstSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TBoolI('AA@2019-09-01')
+        >>> TBoolInstSet('AA@2019-09-01')
 
     Another possibility is to give a tuple or list of arguments,
     which can be instances of ``str`` or ``TBoolInst``.
 
-        >>> TBoolI('AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01')
-        >>> TBoolI(TBoolInst('AA@2019-09-01 00:00:00+01'), TBoolInst('BB@2019-09-02 00:00:00+01'), TBoolInst('AA@2019-09-03 00:00:00+01'))
-        >>> TBoolI(['AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01'])
-        >>> TBoolI([TBoolInst('AA@2019-09-01 00:00:00+01'), TBoolInst('BB@2019-09-02 00:00:00+01'), TBoolInst('AA@2019-09-03 00:00:00+01')])
+        >>> TBoolInstSet('AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01')
+        >>> TBoolInstSet(TBoolInst('AA@2019-09-01 00:00:00+01'), TBoolInst('BB@2019-09-02 00:00:00+01'), TBoolInst('AA@2019-09-03 00:00:00+01'))
+        >>> TBoolInstSet(['AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01'])
+        >>> TBoolInstSet([TBoolInst('AA@2019-09-01 00:00:00+01'), TBoolInst('BB@2019-09-02 00:00:00+01'), TBoolInst('AA@2019-09-03 00:00:00+01')])
 
     """
 
+    ComponentClass = TBoolInst
+
     def __init__(self,  *argv):
-        TemporalI.BaseClass = bool
-        TemporalI.ComponentClass = TBoolInst
         super().__init__(*argv)
 
 
-class TBoolSeq(TemporalSeq, TBool):
+class TBoolSeq(TSequence, TBool):
     """
-    Class for representing temporal Booleans of sequence duration.
+    Class for representing temporal Booleans of sequence subtype.
 
     ``TBoolSeq`` objects can be created with a single argument of type string
     as in MobilityDB.
@@ -134,11 +162,9 @@ class TBoolSeq(TemporalSeq, TBool):
 
     """
 
+    ComponentClass = TBoolInst
+
     def __init__(self, instantList, lower_inc=None, upper_inc=None):
-        TemporalSeq.BaseClass = bool
-        TemporalSeq.BaseClassDiscrete = True
-        TemporalSeq.ComponentClass = TBoolInst
-        self._interp = 'Stepwise'
         super().__init__(instantList, lower_inc, upper_inc)
 
     @classmethod
@@ -150,29 +176,27 @@ class TBoolSeq(TemporalSeq, TBool):
         return 'Stepwise'
 
 
-class TBoolS(TemporalS, TBool):
+class TBoolSeqSet(TSequenceSet, TBool):
     """
-    Class for representing temporal Booleans of sequence set duration.
+    Class for representing temporal Booleans of sequence set subtype.
 
-    ``TBoolS`` objects can be created with a single argument of type string
+    ``TBoolSeqSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TBoolS('{[true@2019-09-01 00:00:00+01], [false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]}')
+        >>> TBoolSeqSet('{[true@2019-09-01 00:00:00+01], [false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]}')
 
     Another possibility is to give the list of composing sequences, which
     can be instances of ``str`` or ``TBoolSeq``.
 
-        >>> TBoolS(['[true@2019-09-01 00:00:00+01]', '[false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]'])
-        >>> TBoolS([TBoolSeq('[true@2019-09-01 00:00:00+01]'), TBoolSeq('[false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]')])
-        >>> TBoolS([TBoolSeq('[true@2019-09-01 00:00:00+01]'), TBoolSeq('[false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]')])
+        >>> TBoolSeqSet(['[true@2019-09-01 00:00:00+01]', '[false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]'])
+        >>> TBoolSeqSet([TBoolSeq('[true@2019-09-01 00:00:00+01]'), TBoolSeq('[false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]')])
+        >>> TBoolSeqSet([TBoolSeq('[true@2019-09-01 00:00:00+01]'), TBoolSeq('[false@2019-09-02 00:00:00+01, true@2019-09-03 00:00:00+01]')])
 
     """
 
+    ComponentClass = TBoolSeq
+
     def __init__(self, sequenceList):
-        TemporalS.BaseClass = bool
-        TemporalS.BaseClassDiscrete = True
-        TemporalS.ComponentClass = TBoolSeq
-        self._interp = 'Stepwise'
         super().__init__(sequenceList)
 
     @classmethod
