@@ -1,16 +1,46 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
+from datetime import datetime
 from spans.types import floatrange
-from mobilitydb.temporal import Temporal, TemporalInst, TemporalI, TemporalSeq, TemporalS
+from mobilitydb.temporal import Temporal, TInstant, TInstantSet, TSequence, TSequenceSet
 
 
 class TFloat(Temporal):
     """
-    Abstract class for representing temporal floats of any duration.
+    Abstract class for representing temporal floats of any subtype.
     """
 
+    BaseClass = float
+    BaseClassDiscrete = False
+
     @property
     def valueRange(self):
         """
-        Distinct values
+        Range of values taken by the temporal value as defined by its minimum and maximum value
         """
         return floatrange(self.minValue, self.maxValue, True, True)
 
@@ -21,7 +51,7 @@ class TFloat(Temporal):
         if value.startswith('Interp=Stepwise;'):
             value1 = value.replace('Interp=Stepwise;', '')
             if value1[0] == '{':
-                return TFloatS(value)
+                return TFloatSeqSet(value)
             else:
                 return TFloatSeq(value)
         elif value[0] != '{' and value[0] != '[' and value[0] != '(':
@@ -30,21 +60,21 @@ class TFloat(Temporal):
             return TFloatSeq(value)
         elif value[0] == '{':
             if value[1] == '[' or value[1] == '(':
-                return TFloatS(value)
+                return TFloatSeqSet(value)
             else:
-                return TFloatI(value)
+                return TFloatInstSet(value)
         raise Exception("ERROR: Could not parse temporal float value")
 
     @staticmethod
     def write(value):
         if not isinstance(value, TFloat):
-            raise ValueError('TFloat value must subclass TFloat class')
+            raise ValueError('Value must be an instance of a subclass of TFloat')
         return value.__str__().strip("'")
 
 
-class TFloatInst(TemporalInst, TFloat):
+class TFloatInst(TInstant, TFloat):
     """
-    Class for representing temporal floats of instant duration.
+    Class for representing temporal floats of instant subtype.
 
     ``TFloatInst`` objects can be created with a single argument of type string
     as in MobilityDB.
@@ -62,7 +92,6 @@ class TFloatInst(TemporalInst, TFloat):
     """
 
     def __init__(self, value, time=None):
-        TemporalInst.BaseClass = float
         super().__init__(value, time)
 
     @property
@@ -73,28 +102,28 @@ class TFloatInst(TemporalInst, TFloat):
         return [floatrange(self._value, self._value, True, True)]
 
 
-class TFloatI(TemporalI, TFloat):
+class TFloatInstSet(TInstantSet, TFloat):
     """
-    Class for representing temporal floats of instant set duration.
+    Class for representing temporal floats of instant set subtype.
 
-    ``TFloatI`` objects can be created with a single argument of type string
+    ``TFloatInstSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TFloatI('10.0@2019-09-01')
+        >>> TFloatInstSet('10.0@2019-09-01')
 
     Another possibility is to give a tuple or list of composing instants,
     which can be instances of ``str`` or ``TFloatInst``.
 
-        >>> TFloatI('10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01')
-        >>> TFloatI(TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01'))
-        >>> TFloatI(['10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01'])
-        >>> TFloatI([TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01')])
+        >>> TFloatInstSet('10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01')
+        >>> TFloatInstSet(TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01'))
+        >>> TFloatInstSet(['10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01'])
+        >>> TFloatInstSet([TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'), TFloatInst('10.0@2019-09-03 00:00:00+01')])
 
     """
 
+    ComponentClass = TFloatInst
+
     def __init__(self,  *argv):
-        TemporalI.BaseClass = float
-        TemporalI.ComponentClass = TFloatInst
         super().__init__(*argv)
 
     @property
@@ -106,9 +135,9 @@ class TFloatI(TemporalI, TFloat):
         return [floatrange(value, value, True, True) for value in values]
 
 
-class TFloatSeq(TemporalSeq, TFloat):
+class TFloatSeq(TSequence, TFloat):
     """
-    Class for representing temporal floats of sequence duration.
+    Class for representing temporal floats of sequence subtype.
 
     ``TFloatSeq`` objects can be created with a single argument of type string
     as in MobilityDB.
@@ -135,10 +164,9 @@ class TFloatSeq(TemporalSeq, TFloat):
 
     """
 
+    ComponentClass = TFloatInst
+
     def __init__(self, instantList, lower_inc=None, upper_inc=None, interp=None):
-        TemporalSeq.BaseClass = float
-        TemporalSeq.BaseClassDiscrete = False
-        TemporalSeq.ComponentClass = TFloatInst
         super().__init__(instantList, lower_inc, upper_inc, interp)
 
     @property
@@ -148,6 +176,21 @@ class TFloatSeq(TemporalSeq, TFloat):
         """
         return self._interp
 
+    def _interpolate(self, inst1, inst2, timestamp):
+        """
+        Interpolate the temporal value at a timestamp between inst1 and inst2.
+        """
+        # preconditions
+        if not (isinstance(inst1, TFloatInst) and
+            isinstance(inst2, TFloatInst) and isinstance(timestamp, datetime) and
+            inst1._time < timestamp and timestamp < inst2._time):
+            Exception("Erroneous arguments for function TFloatSeq._interpolate")
+
+        duration1 = timestamp - inst1._time
+        duration2 = inst2._time - inst1._time
+        ratio = duration1.total_seconds() / duration2.total_seconds();
+        return inst1._value + (inst2._value - inst1._value) * ratio;
+
     @property
     def getValues(self):
         """
@@ -166,15 +209,15 @@ class TFloatSeq(TemporalSeq, TFloat):
         return [floatrange(min, max, min_inc, max_inc)]
 
 
-class TFloatS(TemporalS, TFloat):
+class TFloatSeqSet(TSequenceSet, TFloat):
     """
-    Class for representing temporal floats of sequence duration.
+    Class for representing temporal floats of sequence subtype.
 
-    ``TFloatS`` objects can be created with a single argument of type string
+    ``TFloatSeqSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TFloatS('{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
-        >>> TFloatS('Interp=Stepwise;{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
+        >>> TFloatSeqSet('{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
+        >>> TFloatSeqSet('Interp=Stepwise;{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}')
 
     Another possibility is to give the arguments as follows:
 
@@ -185,19 +228,18 @@ class TFloatS(TemporalS, TFloat):
 
     Some examples are shown next.
 
-        >>> TFloatS(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'])
-        >>> TFloatS(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Linear')
-        >>> TFloatS(['Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Stepwise')
-        >>> TFloatS([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')])
-        >>> TFloatS([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'),  TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Linear')
-        >>> TFloatS([TFloatSeq('Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Stepwise')
+        >>> TFloatSeqSet(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'])
+        >>> TFloatSeqSet(['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Linear')
+        >>> TFloatSeqSet(['Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'], 'Stepwise')
+        >>> TFloatSeqSet([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')])
+        >>> TFloatSeqSet([TFloatSeq('[10.0@2019-09-01 00:00:00+01]'),  TFloatSeq('[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Linear')
+        >>> TFloatSeqSet([TFloatSeq('Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]'), TFloatSeq('Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Stepwise')
 
     """
 
+    ComponentClass = TFloatSeq
+
     def __init__(self, sequenceList, interp=None):
-        TemporalS.BaseClass = float
-        TemporalS.BaseClassDiscrete = False
-        TemporalS.ComponentClass = TFloatSeq
         super().__init__(sequenceList, interp)
 
     @property
