@@ -1,12 +1,41 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from spans.types import intrange
-from mobilitydb.temporal import Temporal, TemporalInst, TemporalI, TemporalSeq, TemporalS
+from mobilitydb.temporal import Temporal, TInstant, TInstantSet, TSequence, TSequenceSet
 
 
 class TInt(Temporal):
     """
-    Abstract class for representing temporal integers of any duration.
+    Abstract class for representing temporal integers of any subtype.
     """
 
+    BaseClass = int
+    BaseClassDiscrete = True
+
     @staticmethod
     def read_from_cursor(value, cursor=None):
         if not value:
@@ -17,28 +46,28 @@ class TInt(Temporal):
             return TIntSeq(value)
         elif value[0] == '{':
             if value[1] == '[' or value[1] == '(':
-                return TIntS(value)
+                return TIntSeqSet(value)
             else:
-                return TIntI(value)
+                return TIntInstSet(value)
         raise Exception("ERROR: Could not parse temporal integer value")
 
     @staticmethod
     def write(value):
         if not isinstance(value, TInt):
-            raise ValueError('TInt value must subclass TInt class')
+            raise ValueError('Value must be an instance of a subclass of TInt')
         return value.__str__().strip("'")
 
     @property
     def valueRange(self):
         """
-        Minimun and maximum values represented as an integer range
+        Range of values taken by the temporal value as defined by its minimum and maximum value
         """
         return intrange(self.minValue, self.maxValue, True, True)
 
 
-class TIntInst(TemporalInst, TInt):
+class TIntInst(TInstant, TInt):
     """
-    Class for representing temporal integers of instant duration.
+    Class for representing temporal integers of instant subtype.
 
     ``TIntInst`` objects can be created with a single argument of type string
     as in MobilityDB.
@@ -56,38 +85,37 @@ class TIntInst(TemporalInst, TInt):
     """
 
     def __init__(self, value, time=None):
-        TemporalInst.BaseClass = int
         super().__init__(value, time)
 
 
-class TIntI(TemporalI, TInt):
+class TIntInstSet(TInstantSet, TInt):
     """
-    Class for representing temporal integers of instant set duration.
+    Class for representing temporal integers of instant set subtype.
 
-    ``TIntI`` objects can be created with a single argument of type string
+    ``TIntInstSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TIntI('10@2019-09-01')
+        >>> TIntInstSet('10@2019-09-01')
 
     Another possibility is to give a tuple or list of composing instants,
     which can be instances of ``str`` or ``TIntInst``.
 
-        >>> TIntI('10@2019-09-01 00:00:00+01', '20@2019-09-02 00:00:00+01', '10@2019-09-03 00:00:00+01')
-        >>> TIntI(TIntInst('10@2019-09-01 00:00:00+01'), TIntInst('20@2019-09-02 00:00:00+01'), TIntInst('10@2019-09-03 00:00:00+01'))
-        >>> TIntI(['10@2019-09-01 00:00:00+01', '20@2019-09-02 00:00:00+01', '10@2019-09-03 00:00:00+01'])
-        >>> TIntI([TIntInst('10@2019-09-01 00:00:00+01'), TIntInst('20@2019-09-02 00:00:00+01'), TIntInst('10@2019-09-03 00:00:00+01')])
+        >>> TIntInstSet('10@2019-09-01 00:00:00+01', '20@2019-09-02 00:00:00+01', '10@2019-09-03 00:00:00+01')
+        >>> TIntInstSet(TIntInst('10@2019-09-01 00:00:00+01'), TIntInst('20@2019-09-02 00:00:00+01'), TIntInst('10@2019-09-03 00:00:00+01'))
+        >>> TIntInstSet(['10@2019-09-01 00:00:00+01', '20@2019-09-02 00:00:00+01', '10@2019-09-03 00:00:00+01'])
+        >>> TIntInstSet([TIntInst('10@2019-09-01 00:00:00+01'), TIntInst('20@2019-09-02 00:00:00+01'), TIntInst('10@2019-09-03 00:00:00+01')])
 
     """
 
+    ComponentClass = TIntInst
+
     def __init__(self,  *argv):
-        TemporalI.BaseClass = int
-        TemporalI.ComponentClass = TIntInst
         super().__init__(*argv)
 
 
-class TIntSeq(TemporalSeq, TInt):
+class TIntSeq(TSequence, TInt):
     """
-    Class for representing temporal integers of sequence duration.
+    Class for representing temporal integers of sequence subtype.
 
     ``TIntSeq`` objects can be created with a single argument of type string
     as in MobilityDB.
@@ -111,10 +139,9 @@ class TIntSeq(TemporalSeq, TInt):
 
     """
 
+    ComponentClass = TIntInst
+
     def __init__(self, instantList, lower_inc=None, upper_inc=None):
-        TemporalSeq.BaseClass = int
-        TemporalSeq.BaseClassDiscrete = True
-        TemporalSeq.ComponentClass = TIntInst
         super().__init__(instantList, lower_inc, upper_inc)
 
     @classmethod
@@ -126,28 +153,27 @@ class TIntSeq(TemporalSeq, TInt):
         return 'Stepwise'
 
 
-class TIntS(TemporalS, TInt):
+class TIntSeqSet(TSequenceSet, TInt):
     """
-    Class for representing temporal integers of sequence duration.
+    Class for representing temporal integers of sequence subtype.
 
-    ``TIntS`` objects can be created with a single argument of type string
+    ``TIntSeqSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TIntS('{[10@2019-09-01 00:00:00+01], [20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]}')
+        >>> TIntSeqSet('{[10@2019-09-01 00:00:00+01], [20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]}')
 
     Another possibility is to give the list of composing sequences, which
     can be instances of ``str`` or ``TIntSeq``.
 
-        >>> TIntS(['[10@2019-09-01 00:00:00+01]', '[20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]'])
-        >>> TIntS([TIntSeq('[10@2019-09-01 00:00:00+01]'), TIntSeq('[20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]')])
-        >>> TIntS([TIntSeq('[10@2019-09-01 00:00:00+01]'), TIntSeq('[20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]')])
+        >>> TIntSeqSet(['[10@2019-09-01 00:00:00+01]', '[20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]'])
+        >>> TIntSeqSet([TIntSeq('[10@2019-09-01 00:00:00+01]'), TIntSeq('[20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]')])
+        >>> TIntSeqSet([TIntSeq('[10@2019-09-01 00:00:00+01]'), TIntSeq('[20@2019-09-02 00:00:00+01, 10@2019-09-03 00:00:00+01]')])
 
     """
 
+    ComponentClass = TIntSeq
+
     def __init__(self, sequenceList):
-        TemporalS.BaseClass = int
-        TemporalS.BaseClassDiscrete = True
-        TemporalS.ComponentClass = TIntSeq
         super().__init__(sequenceList)
 
     @classmethod
