@@ -1,9 +1,35 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import re
 from datetime import datetime
 from dateutil.parser import parse
 from postgis import Geometry, Point, MultiPoint, LineString, GeometryCollection, MultiLineString
-from mobilitydb.temporal import Temporal, TemporalInst, TemporalI, TemporalSeq, TemporalS
-from mobilitydb.temporal.temporal_parser import parse_temporalinst, parse_temporali, parse_temporalseq, parse_temporals
+from mobilitydb.temporal import Temporal, TInstant, TInstantSet, TSequence, TSequenceSet
+from mobilitydb.temporal.temporal_parser import parse_temporalinst, parse_temporalinstset, parse_temporalseq, parse_temporalseqset
 
 
 # Add method to Point to make the class hashable
@@ -13,9 +39,9 @@ def __hash__(self):
 setattr(Point, '__hash__', __hash__)
 
 
-class TPointInst(TemporalInst):
+class TPointInst(TInstant):
     """
-    Abstract class for representing temporal points of instant duration.
+    Abstract class for representing temporal points of instant subtype.
     """
 
     def __init__(self, value, time=None, srid=None):
@@ -31,7 +57,8 @@ class TPointInst(TemporalInst):
                     srid = srid_str
                     value = re.sub(r'^(SRID|srid)\s*=\s*\d+\s*(;|,)\s*', '', value)
                 else:
-                    srid = 0
+                    if srid is None:
+                        srid = 0
                 #Parse without the eventual "srid=xxx;" prefix
                 couple = parse_temporalinst(value, 0)
                 value = couple[2][0]
@@ -77,9 +104,9 @@ class TPointInst(TemporalInst):
         return self._value
 
 
-class TPointI(TemporalI):
+class TPointInstSet(TInstantSet):
     """
-    Abstract class for representing temporal points of instant set duration.
+    Abstract class for representing temporal points of instant set subtype.
     """
 
     def __init__(self,  *argv, srid=None):
@@ -97,17 +124,17 @@ class TPointI(TemporalI):
             else:
                 instantList = argv[0]
             # Parse without the eventual "srid=xxx;" prefix
-            elements = parse_temporali(instantList, 0)
+            elements = parse_temporalinstset(instantList, 0)
             for inst in elements[2]:
-                self._instantList.append(TemporalI.ComponentClass(inst[0], inst[1], srid=srid))
+                self._instantList.append(self.ComponentClass(inst[0], inst[1], srid=srid))
         # Constructor with a single argument of type list
         elif len(argv) == 1 and isinstance(argv[0], list):
             # List of strings representing instant values
             if all(isinstance(arg, str) for arg in argv[0]):
                 for arg in argv[0]:
-                    self._instantList.append(TemporalI.ComponentClass(arg))
+                    self._instantList.append(self.ComponentClass(arg, srid=srid))
             # List of instant values
-            elif all(isinstance(arg, TemporalI.ComponentClass) for arg in argv[0]):
+            elif all(isinstance(arg, self.ComponentClass) for arg in argv[0]):
                 for arg in argv[0]:
                     self._instantList.append(arg)
             else:
@@ -117,9 +144,9 @@ class TPointI(TemporalI):
             # Arguments are of type string
             if all(isinstance(arg, str) for arg in argv):
                 for arg in argv:
-                    self._instantList.append(TemporalI.ComponentClass(arg))
+                    self._instantList.append(self.ComponentClass(arg, srid=srid))
             # Arguments are of type instant
-            elif all(isinstance(arg, TemporalI.ComponentClass) for arg in argv):
+            elif all(isinstance(arg, self.ComponentClass) for arg in argv):
                 for arg in argv:
                     self._instantList.append(arg)
             else:
@@ -146,9 +173,9 @@ class TPointI(TemporalI):
         return MultiPoint(values)
 
 
-class TPointSeq(TemporalSeq):
+class TPointSeq(TSequence):
     """
-    Abstract class for representing temporal points of sequence duration.
+    Abstract class for representing temporal points of sequence subtype.
     """
 
     def __init__(self, instantList, lower_inc=None, upper_inc=None, interp=None, srid=None):
@@ -171,14 +198,14 @@ class TPointSeq(TemporalSeq):
             # Parse without the eventual "srid=xxx;" prefix
             elements = parse_temporalseq(instantList, 0)
             for inst in elements[2][0]:
-                self._instantList.append(TemporalSeq.ComponentClass(inst[0], inst[1], srid=srid))
+                self._instantList.append(self.ComponentClass(inst[0], inst[1], srid=srid))
             self._lower_inc = elements[2][1]
             self._upper_inc = elements[2][2]
             # Set interpolation with the argument or the flag from the string if given
             if interp is not None:
                 self._interp = interp
             else:
-                if self.__class__.BaseClassDiscrete:
+                if self.BaseClassDiscrete:
                     self._interp = 'Stepwise'
                 else:
                     self._interp = elements[2][3] if elements[2][3] is not None else 'Linear'
@@ -187,9 +214,9 @@ class TPointSeq(TemporalSeq):
             # List of strings representing instant values
             if all(isinstance(arg, str) for arg in instantList):
                 for arg in instantList:
-                    self._instantList.append(TemporalSeq.ComponentClass(arg))
+                    self._instantList.append(self.ComponentClass(arg, srid=srid))
             # List of instant values
-            elif all(isinstance(arg, TemporalSeq.ComponentClass) for arg in instantList):
+            elif all(isinstance(arg, self.ComponentClass) for arg in instantList):
                 for arg in instantList:
                     self._instantList.append(arg)
             else:
@@ -200,7 +227,7 @@ class TPointSeq(TemporalSeq):
             if interp is not None:
                 self._interp = interp
             else:
-                self._interp = 'Stepwise' if self.__class__.BaseClassDiscrete else 'Linear'
+                self._interp = 'Stepwise' if self.BaseClassDiscrete else 'Linear'
         else:
             raise Exception("ERROR: Could not parse temporal sequence value")
         # Verify validity of the resulting instance
@@ -234,9 +261,9 @@ class TPointSeq(TemporalSeq):
         return result
 
 
-class TPointS(TemporalS):
+class TPointSeqSet(TSequenceSet):
     """
-    Abstract class for representing temporal points of sequence set duration.
+    Abstract class for representing temporal points of sequence set subtype.
     """
 
     def __init__(self, sequenceList, interp=None, srid=None):
@@ -255,22 +282,22 @@ class TPointS(TemporalS):
                 srid = srid_str
                 sequenceList = re.sub(r'^(SRID|srid)\s*=\s*\d+\s*(;|,)\s*', '', sequenceList)
             # Parse without the eventual "srid=xxx;" prefix
-            elements = parse_temporals(sequenceList, 0)
+            elements = parse_temporalseqset(sequenceList, 0)
             seqList = []
             for seq in elements[2][0]:
                 instList = []
                 for inst in seq[0]:
-                    instList.append(TemporalS.ComponentClass.ComponentClass(inst[0], inst[1], srid=srid))
-                if self.__class__.BaseClassDiscrete:
-                    seqList.append(TemporalS.ComponentClass(instList, seq[1], seq[2]))
+                    instList.append(self.ComponentClass.ComponentClass(inst[0], inst[1], srid=srid))
+                if self.BaseClassDiscrete:
+                    seqList.append(self.ComponentClass(instList, seq[1], seq[2]))
                 else:
-                    seqList.append(TemporalS.ComponentClass(instList, seq[1], seq[2], elements[2][1], srid=srid))
+                    seqList.append(self.ComponentClass(instList, seq[1], seq[2], elements[2][1], srid=srid))
             self._sequenceList = seqList
             # Set interpolation with the argument or the flag from the string if given
             if interp is not None:
                 self._interp = interp
             else:
-                if self.__class__.BaseClassDiscrete:
+                if self.BaseClassDiscrete:
                     self._interp = 'Stepwise'
                 else:
                     self._interp = elements[2][1] if elements[2][1] is not None else 'Linear'
@@ -279,9 +306,9 @@ class TPointS(TemporalS):
             # List of strings representing periods
             if all(isinstance(sequence, str) for sequence in sequenceList):
                 for sequence in sequenceList:
-                    self._sequenceList.append(self.__class__.ComponentClass(sequence))
+                    self._sequenceList.append(self.ComponentClass(sequence))
             # List of periods
-            elif all(isinstance(sequence, self.__class__.ComponentClass) for sequence in sequenceList):
+            elif all(isinstance(sequence, self.ComponentClass) for sequence in sequenceList):
                 for sequence in sequenceList:
                     self._sequenceList.append(sequence)
             else:
@@ -290,7 +317,7 @@ class TPointS(TemporalS):
             if interp is not None:
                 self._interp = interp
             else:
-                self._interp = 'Stepwise' if self.__class__.BaseClassDiscrete else 'Linear'
+                self._interp = 'Stepwise' if self.BaseClassDiscrete else 'Linear'
         else:
             raise Exception("ERROR: Could not parse temporal sequence set value")
         # Verify validity of the resulting instance
@@ -329,9 +356,12 @@ class TPointS(TemporalS):
 
 class TGeomPoint(Temporal):
     """
-    Abstract class for representing temporal geometric or geographic points of any duration.
+    Abstract class for representing temporal geometric or geographic points of any subtype.
     """
 
+    BaseClass = Point
+    BaseClassDiscrete = False
+
     @staticmethod
     def read_from_cursor(value, cursor=None):
         if not value:
@@ -339,7 +369,7 @@ class TGeomPoint(Temporal):
         if value.startswith('Interp=Stepwise;'):
             value1 = value.replace('Interp=Stepwise;', '')
             if value1[0] == '{':
-                return TGeomPointS(value)
+                return TGeomPointSeqSet(value)
             else:
                 return TGeomPointSeq(value)
         elif value[0] != '{' and value[0] != '[' and value[0] != '(':
@@ -348,9 +378,9 @@ class TGeomPoint(Temporal):
             return TGeomPointSeq(value)
         elif value[0] == '{':
             if value[1] == '[' or value[1] == '(':
-                return TGeomPointS(value)
+                return TGeomPointSeqSet(value)
             else:
-                return TGeomPointI(value)
+                return TGeomPointInstSet(value)
         raise Exception("ERROR: Could not parse temporal point value")
 
     @staticmethod
@@ -377,9 +407,12 @@ class TGeomPoint(Temporal):
 
 class TGeogPoint(Temporal):
     """
-    Abstract class for representing temporal geographic points of any duration.
+    Abstract class for representing temporal geographic points of any subtype.
     """
 
+    BaseClass = Point
+    BaseClassDiscrete = False
+
     @staticmethod
     def read_from_cursor(value, cursor=None):
         if not value:
@@ -387,7 +420,7 @@ class TGeogPoint(Temporal):
         if value.startswith('Interp=Stepwise;'):
             value1 = value.replace('Interp=Stepwise;', '')
             if value1[0] == '{':
-                return TGeogPointS(value)
+                return TGeogPointSeqSet(value)
             else:
                 return TGeogPointSeq(value)
         elif value[0] != '{' and value[0] != '[' and value[0] != '(':
@@ -396,9 +429,9 @@ class TGeogPoint(Temporal):
             return TGeogPointSeq(value)
         elif value[0] == '{':
             if value[1] == '[' or value[1] == '(':
-                return TGeogPointS(value)
+                return TGeogPointSeqSet(value)
             else:
-                return TGeogPointI(value)
+                return TGeogPointInstSet(value)
         raise Exception("ERROR: Could not parse temporal point value")
 
     @staticmethod
@@ -425,7 +458,7 @@ class TGeogPoint(Temporal):
 
 class TGeomPointInst(TPointInst, TGeomPoint):
     """
-    Class for representing temporal geometric points of instant duration.
+    Class for representing temporal geometric points of instant subtype.
 
     ``TGeomPointInst`` objects can be created with a single argument of type
     string as in MobilityDB.
@@ -446,13 +479,12 @@ class TGeomPointInst(TPointInst, TGeomPoint):
     """
 
     def __init__(self, value, time=None, srid=None):
-        TemporalInst.BaseClass = Point
         super().__init__(value, time, srid)
 
 
 class TGeogPointInst(TPointInst, TGeogPoint):
     """
-    Class for representing temporal geographic points of instant duration.
+    Class for representing temporal geographic points of instant subtype.
 
     ``TGeogPointInst`` objects can be created with a single argument of type
     string as in MobilityDB.
@@ -472,65 +504,64 @@ class TGeogPointInst(TPointInst, TGeogPoint):
     """
 
     def __init__(self, value, time=None, srid=None):
-        TemporalInst.BaseClass = Point
         super().__init__(value, time, srid)
 
 
-class TGeomPointI(TPointI, TGeomPoint):
+class TGeomPointInstSet(TPointInstSet, TGeomPoint):
     """
-    Class for representing temporal geometric points of instant set duration.
+    Class for representing temporal geometric points of instant set subtype.
 
-    ``TGeomPointI`` objects can be created with a single argument of type
+    ``TGeomPointInstSet`` objects can be created with a single argument of type
     string as in MobilityDB.
 
-        >>> TGeomPointI('Point(10.0 10.0)@2019-09-01')
+        >>> TGeomPointInstSet('Point(10.0 10.0)@2019-09-01')
 
     Another possibility is to give a tuple or list of arguments specifying
     the composing instants, which can be instances of ``str`` or
     ``TGeomPointInst``.
 
-        >>> TGeomPointI('Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01')
-        >>> TGeomPointI(TGeomPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeomPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeomPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01'))
-        >>> TGeomPointI(['Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01'])
-        >>> TGeomPointI([TGeomPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeomPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeomPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01')])
+        >>> TGeomPointInstSet('Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01')
+        >>> TGeomPointInstSet(TGeomPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeomPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeomPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01'))
+        >>> TGeomPointInstSet(['Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01'])
+        >>> TGeomPointInstSet([TGeomPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeomPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeomPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01')])
 
     """
 
+    ComponentClass = TGeomPointInst
+
     def __init__(self,  *argv, **kwargs):
-        TemporalI.BaseClass = Point
-        TemporalI.ComponentClass = TGeomPointInst
         super().__init__(*argv, **kwargs)
 
 
-class TGeogPointI(TPointI, TGeogPoint):
+class TGeogPointInstSet(TPointInstSet, TGeogPoint):
     """
-    Class for representing temporal geometric points of instant set duration.
+    Class for representing temporal geometric points of instant set subtype.
 
-    ``TGeogPointI`` objects can be created with a single argument of type
+    ``TGeogPointInstSet`` objects can be created with a single argument of type
     string as in MobilityDB.
 
-        >>> TGeogPointI('Point(10.0 10.0)@2019-09-01')
+        >>> TGeogPointInstSet('Point(10.0 10.0)@2019-09-01')
 
     Another possibility is to give a tuple or list of arguments specifying
     the composing instants, which can be instances of ``str`` or
     ``TGeogPointInst``.
 
-        >>> TGeogPointI('Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01')
-        >>> TGeogPointI(TGeogPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeogPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeogPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01'))
-        >>> TGeogPointI(['Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01'])
-        >>> TGeogPointI([TGeogPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeogPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeogPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01')])
+        >>> TGeogPointInstSet('Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01')
+        >>> TGeogPointInstSet(TGeogPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeogPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeogPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01'))
+        >>> TGeogPointInstSet(['Point(10.0 10.0)@2019-09-01 00:00:00+01', 'Point(20.0 20.0)@2019-09-02 00:00:00+01', 'Point(10.0 10.0)@2019-09-03 00:00:00+01'])
+        >>> TGeogPointInstSet([TGeogPointInst('Point(10.0 10.0)@2019-09-01 00:00:00+01'), TGeogPointInst('Point(20.0 20.0)@2019-09-02 00:00:00+01'), TGeogPointInst('Point(10.0 10.0)@2019-09-03 00:00:00+01')])
 
     """
 
+    ComponentClass = TGeogPointInst
+
     def __init__(self,  *argv, **kwargs):
-        TemporalI.BaseClass = Point
-        TemporalI.ComponentClass = TGeogPointInst
         super().__init__(*argv, **kwargs)
 
 
 class TGeomPointSeq(TPointSeq, TGeomPoint):
     """
-    Class for representing temporal geometric points of sequence duration.
+    Class for representing temporal geometric points of sequence subtype.
 
     ``TGeomPointSeq`` objects can be created with a single argument of type
     string as in MobilityDB.
@@ -558,16 +589,35 @@ class TGeomPointSeq(TPointSeq, TGeomPoint):
 
     """
 
+    ComponentClass = TGeomPointInst
+
     def __init__(self, instantList, lower_inc=None, upper_inc=None, interp=None, srid=None):
-        TemporalSeq.BaseClass = Point
-        TemporalSeq.BaseClassDiscrete = False
-        TemporalSeq.ComponentClass = TGeomPointInst
         super().__init__(instantList, lower_inc, upper_inc, interp, srid)
 
+    def _interpolate(self, inst1, inst2, timestamp):
+        """
+        Interpolate the temporal value at a timestamp between inst1 and inst2.
+        """
+        # preconditions
+        if not (isinstance(inst1, TGeomPointInst) and isinstance(inst2, TGeomPointInst) and
+            isinstance(timestamp, datetime) and inst1._time < timestamp and timestamp < inst2._time):
+            Exception("Erroneous arguments for function TGeomPointSeq._interpolate")
+
+        duration1 = timestamp - inst1._time
+        duration2 = inst2._time - inst1._time
+        ratio = duration1.total_seconds() / duration2.total_seconds();
+        x = inst1._value.x + (inst2._value.x - inst1._value.x) * ratio;
+        y = inst1._value.y + (inst2._value.y - inst1._value.y) * ratio;
+        if inst1._value.z is not None and inst2._value.z is not None:
+            z = inst1._value.z + (inst2._value.z - inst1._value.z) * ratio;
+            return Point(x,y,z);
+        else:
+            return Point(x,y);
+
 
 class TGeogPointSeq(TPointSeq, TGeogPoint):
     """
-    Class for representing temporal geographic points of sequence duration.
+    Class for representing temporal geographic points of sequence subtype.
 
     ``TGeogPointSeq`` objects can be created with a single argument of type
     string as in MobilityDB.
@@ -595,22 +645,21 @@ class TGeogPointSeq(TPointSeq, TGeogPoint):
 
     """
 
+    ComponentClass = TGeogPointInst
+
     def __init__(self, instantList, lower_inc=None, upper_inc=None, interp=None, srid=None):
-        TemporalSeq.BaseClass = Point
-        TemporalSeq.BaseClassDiscrete = False
-        TemporalSeq.ComponentClass = TGeogPointInst
         super().__init__(instantList, lower_inc, upper_inc, interp, srid)
 
 
-class TGeomPointS(TPointS, TGeomPoint):
+class TGeomPointSeqSet(TPointSeqSet, TGeomPoint):
     """
-    Class for representing temporal geometric points of sequence duration.
+    Class for representing temporal geometric points of sequence subtype.
 
-    ``TGeomPointS`` objects can be created with a single argument of type
+    ``TGeomPointSeqSet`` objects can be created with a single argument of type
     string as in MobilityDB.
 
-        >>> TGeomPointS('{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
-        >>> TGeomPointS('Interp=Stepwise;{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
+        >>> TGeomPointSeqSet('{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
+        >>> TGeomPointSeqSet('Interp=Stepwise;{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
 
     Another possibility is to give the arguments as follows:
 
@@ -623,31 +672,30 @@ class TGeomPointS(TPointS, TGeomPoint):
 
     Some examples are shown next.
 
-        >>> TGeomPointS(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'])
-        >>> TGeomPointS(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Linear')
-        >>> TGeomPointS(['Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Stepwise')
-        >>> TGeomPointS([TGeomPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeomPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')])
-        >>> TGeomPointS([TGeomPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'),  TGeomPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Linear')
-        >>> TGeomPointS([TGeomPointSeq('Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeomPointSeq('Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Stepwise')
+        >>> TGeomPointSeqSet(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'])
+        >>> TGeomPointSeqSet(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Linear')
+        >>> TGeomPointSeqSet(['Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Stepwise')
+        >>> TGeomPointSeqSet([TGeomPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeomPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')])
+        >>> TGeomPointSeqSet([TGeomPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'),  TGeomPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Linear')
+        >>> TGeomPointSeqSet([TGeomPointSeq('Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeomPointSeq('Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Stepwise')
 
     """
 
+    ComponentClass = TGeomPointSeq
+
     def __init__(self, sequenceList, interp=None, srid=None):
-        TemporalS.BaseClass = Point
-        TemporalS.BaseClassDiscrete = False
-        TemporalS.ComponentClass = TGeomPointSeq
         super().__init__(sequenceList, interp, srid)
 
 
-class TGeogPointS(TPointS, TGeogPoint):
+class TGeogPointSeqSet(TPointSeqSet, TGeogPoint):
     """
-    Class for representing temporal geographic points of sequence duration.
+    Class for representing temporal geographic points of sequence subtype.
 
-    ``TGeogPointS`` objects can be created with a single argument of type string
+    ``TGeogPointSeqSet`` objects can be created with a single argument of type string
     as in MobilityDB.
 
-        >>> TGeogPointS('{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
-        >>> TGeogPointS('Interp=Stepwise;{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
+        >>> TGeogPointSeqSet('{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
+        >>> TGeogPointSeqSet('Interp=Stepwise;{[Point(10.0 10.0)@2019-09-01 00:00:00+01], [Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}')
 
     Another possibility is to give the arguments as follows:
 
@@ -660,17 +708,16 @@ class TGeogPointS(TPointS, TGeogPoint):
 
     Some examples are shown next.
 
-        >>> TGeogPointS(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'])
-        >>> TGeogPointS(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Linear')
-        >>> TGeogPointS(['Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Stepwise')
-        >>> TGeogPointS([TGeogPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeogPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')])
-        >>> TGeogPointS([TGeogPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'),  TGeogPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Linear')
-        >>> TGeogPointS([TGeogPointSeq('Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeogPointSeq('Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Stepwise')
+        >>> TGeogPointSeqSet(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'])
+        >>> TGeogPointSeqSet(['[Point(10.0 10.0)@2019-09-01 00:00:00+01]', '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Linear')
+        >>> TGeogPointSeqSet(['Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]', 'Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]'], 'Stepwise')
+        >>> TGeogPointSeqSet([TGeogPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeogPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')])
+        >>> TGeogPointSeqSet([TGeogPointSeq('[Point(10.0 10.0)@2019-09-01 00:00:00+01]'),  TGeogPointSeq('[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Linear')
+        >>> TGeogPointSeqSet([TGeogPointSeq('Interp=Stepwise;[Point(10.0 10.0)@2019-09-01 00:00:00+01]'), TGeogPointSeq('Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')], 'Stepwise')
 
     """
 
+    ComponentClass = TGeogPointSeq
+
     def __init__(self, sequenceList, interp=None, srid=None):
-        TemporalS.BaseClass = Point
-        TemporalS.BaseClassDiscrete = False
-        TemporalS.ComponentClass = TGeogPointSeq
         super().__init__(sequenceList, interp, srid)
