@@ -1,14 +1,43 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from datetime import datetime
 from dateutil.parser import parse
 from mobilitydb.temporal.temporal_parser import parse_temporalinst
-from mobilitydb.temporal import Temporal, TemporalInst, TemporalI, TemporalSeq, TemporalS
+from mobilitydb.temporal import Temporal, TInstant, TInstantSet, TSequence, TSequenceSet
 
 
 class TText(Temporal):
     """
-    Abstract class for representing temporal strings of any duration.
+    Abstract class for representing temporal strings of any subtype.
     """
 
+    BaseClass = str
+    BaseClassDiscrete = True
+
     @staticmethod
     def read_from_cursor(value, cursor=None):
         if not value:
@@ -19,21 +48,21 @@ class TText(Temporal):
             return TTextSeq(value)
         elif value[0] == '{':
             if value[1] == '[' or value[1] == '(':
-                return TTextS(value)
+                return TTextSeqSet(value)
             else:
-                return TTextI(value)
+                return TTextInstSet(value)
         raise Exception("ERROR: Could not parse temporal text value")
 
     @staticmethod
     def write(value):
         if not isinstance(value, TText):
-            raise ValueError('TText value must subclass TText class')
+            raise ValueError('Value must be an instance of a subclass of TText')
         return value.__str__().strip("'")
 
 
-class TTextInst(TemporalInst, TText):
+class TTextInst(TInstant, TText):
     """
-    Class for representing temporal strings of instant duration.
+    Class for representing temporal strings of instant subtype.
 
     ``TTextInst`` objects can be created 
     with a single argument of type string as in MobilityDB.
@@ -55,7 +84,6 @@ class TTextInst(TemporalInst, TText):
     """
 
     def __init__(self, value, time=None):
-        TemporalInst.BaseClass = str
         if(time is None):
             # Constructor with a single argument of type string
             if (isinstance(value, str)):
@@ -77,34 +105,34 @@ class TTextInst(TemporalInst, TText):
         self._time = parse(time) if isinstance(time, str) else time
 
 
-class TTextI(TemporalI, TText):
+class TTextInstSet(TInstantSet, TText):
     """
-    Class for representing temporal strings of instant set duration.
+    Class for representing temporal strings of instant set subtype.
 
-    ``TTextI`` objects can be created 
+    ``TTextInstSet`` objects can be created 
     with a single argument of type string as in MobilityDB.
 
-        >>> TTextI('AA@2019-09-01')
+        >>> TTextInstSet('AA@2019-09-01')
 
     Another possibility is to give a tuple or list of composing instants,
     which can be instances of ``str`` or ``TTextInst``.
 
-        >>> TTextI('AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01')
-        >>> TTextI(TTextInst('AA@2019-09-01 00:00:00+01'), TTextInst('BB@2019-09-02 00:00:00+01'), TTextInst('AA@2019-09-03 00:00:00+01'))
-        >>> TTextI(['AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01'])
-        >>> TTextI([TTextInst('AA@2019-09-01 00:00:00+01'), TTextInst('BB@2019-09-02 00:00:00+01'), TTextInst('AA@2019-09-03 00:00:00+01')])
+        >>> TTextInstSet('AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01')
+        >>> TTextInstSet(TTextInst('AA@2019-09-01 00:00:00+01'), TTextInst('BB@2019-09-02 00:00:00+01'), TTextInst('AA@2019-09-03 00:00:00+01'))
+        >>> TTextInstSet(['AA@2019-09-01 00:00:00+01', 'BB@2019-09-02 00:00:00+01', 'AA@2019-09-03 00:00:00+01'])
+        >>> TTextInstSet([TTextInst('AA@2019-09-01 00:00:00+01'), TTextInst('BB@2019-09-02 00:00:00+01'), TTextInst('AA@2019-09-03 00:00:00+01')])
 
     """
 
+    ComponentClass = TTextInst
+
     def __init__(self,  *argv):
-        TemporalI.BaseClass = str
-        TemporalI.ComponentClass = TTextInst
         super().__init__(*argv)
 
 
-class TTextSeq(TemporalSeq, TText):
+class TTextSeq(TSequence, TText):
     """
-    Class for representing temporal strings of sequence duration.
+    Class for representing temporal strings of sequence subtype.
 
     ``TTextSeq`` objects can be created 
     with a single argument of type string as in MobilityDB.
@@ -128,10 +156,9 @@ class TTextSeq(TemporalSeq, TText):
 
     """
 
+    ComponentClass = TTextInst
+
     def __init__(self, instantList, lower_inc=None, upper_inc=None):
-        TemporalSeq.BaseClass = str
-        TemporalS.BaseClassDiscrete = True
-        TemporalSeq.ComponentClass = TTextInst
         super().__init__(instantList, lower_inc, upper_inc)
 
     @classmethod
@@ -143,27 +170,26 @@ class TTextSeq(TemporalSeq, TText):
         return 'Stepwise'
 
 
-class TTextS(TemporalS, TText):
+class TTextSeqSet(TSequenceSet, TText):
     """
-    Class for representing temporal strings of sequence duration.
+    Class for representing temporal strings of sequence subtype.
 
-    ``TTextS`` objects can be created with a single argument of typestring as in MobilityDB.
+    ``TTextSeqSet`` objects can be created with a single argument of typestring as in MobilityDB.
 
-        >>> TTextS('{[AA@2019-09-01 00:00:00+01], [BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]}')
+        >>> TTextSeqSet('{[AA@2019-09-01 00:00:00+01], [BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]}')
 
     Another possibility is to give the list of composing sequences, which can be
     instances of ``str`` or ``TTextSeq``.
 
-        >>> TTextS(['[AA@2019-09-01 00:00:00+01]', '[BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]'])
-        >>> TTextS([TTextSeq('[AA@2019-09-01 00:00:00+01]'), TTextSeq('[BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]')])
-        >>> TTextS([TTextSeq('[AA@2019-09-01 00:00:00+01]'), TTextSeq('[BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]')])
+        >>> TTextSeqSet(['[AA@2019-09-01 00:00:00+01]', '[BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]'])
+        >>> TTextSeqSet([TTextSeq('[AA@2019-09-01 00:00:00+01]'), TTextSeq('[BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]')])
+        >>> TTextSeqSet([TTextSeq('[AA@2019-09-01 00:00:00+01]'), TTextSeq('[BB@2019-09-02 00:00:00+01, AA@2019-09-03 00:00:00+01]')])
 
     """
 
+    ComponentClass = TTextSeq
+
     def __init__(self, sequenceList):
-        TemporalS.BaseClass = str
-        TemporalS.BaseClassDiscrete = True
-        TemporalS.ComponentClass = TTextSeq
         super().__init__(sequenceList)
 
     @classmethod
