@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 from abc import abstractmethod
 import warnings
 
@@ -10,7 +36,7 @@ except ImportError:
 
 class Temporal:
     """
-    Abstract class for representing temporal values of any duration.
+    Abstract class for representing temporal values of any subtype.
     """
 
     BaseClass = None
@@ -34,10 +60,10 @@ class Temporal:
 
     @classmethod
     @abstractmethod
-    def duration(cls):
+    def tempSubtype(cls):
         """
-        Duration of the temporal value, that is, one of ``'Instant'``,
-        ``'InstantSet'``, ``'Period'``, or ``'PeriodSet'``.
+        Subtype of the temporal value, that is, one of ``'Instant'``,
+        ``'InstantSet'``, ``'Sequence'``, or ``'SequenceSet'``.
         """
         pass
 
@@ -81,6 +107,13 @@ class Temporal:
         """
         pass
 
+    @abstractmethod
+    def valueAtTimestamp(self, timestamp):
+        """
+        Value at timestamp.
+        """
+        pass
+
     @property
     @abstractmethod
     def getTime(self):
@@ -91,17 +124,27 @@ class Temporal:
 
     @property
     @abstractmethod
-    def timespan(self):
+    def duration(self):
         """
         Interval on which the temporal value is defined.
         """
         pass
 
+    @property
+    @abstractmethod
+    def timespan(self):
+        """
+        Interval on which the temporal value is defined ignoring potential
+        time gaps.
+        """
+        pass
+
     @property
     @abstractmethod
     def period(self):
         """
-        Period on which the temporal value is defined ignoring potential time gaps.
+        Period on which the temporal value is defined ignoring potential
+        time gaps.
         """
         pass
 
@@ -197,12 +240,11 @@ class Temporal:
         """
         pass
 
-    @abstractmethod
-    def intersectsTimestampset(self, timestampset):
+    def intersectsTimestampSet(self, timestampset):
         """
         Does the temporal value intersect the timestamp set?
         """
-        pass
+        return any(self.intersectsTimestamp(timestamp) for timestamp in timestampset._datetimeList)
 
     @abstractmethod
     def intersectsPeriod(self, period):
@@ -211,12 +253,11 @@ class Temporal:
         """
         pass
 
-    @abstractmethod
-    def intersectsPeriodset(self, periodset):
+    def intersectsPeriodSet(self, periodset):
         """
         Does the temporal value intersect the period set?
         """
-        pass
+        return any(self.intersectsPeriod(period) for period in periodset._periodList)
 
     # Psycopg2 interface.
     def __conform__(self, protocol):
