@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import datetime
 from dateutil.parser import parse
 import warnings
@@ -105,7 +131,7 @@ class Period:
         return self._upper_inc
 
     @property
-    def timespan(self):
+    def duration(self):
         """
         Time interval on which the period is defined
         """
@@ -119,7 +145,7 @@ class Period:
                       self._lower_inc, self._upper_inc)
 
     @staticmethod
-    def _cmp_bounds(t1, t2, lower1, lower2, inclusive1, inclusive2):
+    def _cmp_boundSeqSet(t1, t2, lower1, lower2, inclusive1, inclusive2):
         # Compare the values
         if t1 < t2:
             return -1
@@ -156,10 +182,10 @@ class Period:
         """
         Do the periods share a timestamp?
         """
-        if ((self._cmp_bounds(self._lower, other._lower, True, True, self._lower_inc, other._lower_inc) >= 0 and
-                     self._cmp_bounds(self._lower, other._upper, True, False, self._lower_inc, other._upper_inc) <= 0) or
-            (self._cmp_bounds(other._lower, self._lower, True, True, other._lower_inc, self._lower_inc) >= 0 and
-                     self._cmp_bounds(other._lower, self._upper, True, False, other._lower_inc, self._upper_inc) <= 0)):
+        if ((self._cmp_boundSeqSet(self._lower, other._lower, True, True, self._lower_inc, other._lower_inc) >= 0 and
+                     self._cmp_boundSeqSet(self._lower, other._upper, True, False, self._lower_inc, other._upper_inc) <= 0) or
+            (self._cmp_boundSeqSet(other._lower, self._lower, True, True, other._lower_inc, self._lower_inc) >= 0 and
+                     self._cmp_boundSeqSet(other._lower, self._upper, True, False, other._lower_inc, self._upper_inc) <= 0)):
             return True
         return False
 
