@@ -1,6 +1,32 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import pytest
 from dateutil.parser import parse
-from mobilitydb.main import TFloatInst, TFloatI, TFloatSeq, TFloatS
+from mobilitydb.main import TFloatInst, TFloatInstSet, TFloatSeq, TFloatSeqSet
 
 pytestmark = pytest.mark.asyncio
 
@@ -17,7 +43,7 @@ async def test_tfloatinst_constructors(connection, expected_tfloatinst):
     result = await connection.fetchval('SELECT temp FROM tbl_tfloatinst WHERE temp=$1', params, column=0)
     assert result == TFloatInst(expected_tfloatinst)
 
-@pytest.mark.parametrize('expected_tfloati', [
+@pytest.mark.parametrize('expected_tfloatinstset', [
     '{10.0@2019-09-01 00:00:00+01, 20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01}',
     ('10.0@2019-09-01 00:00:00+01', '20.0@2019-09-02 00:00:00+01', '10.0@2019-09-03 00:00:00+01'),
     (TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'),
@@ -26,17 +52,17 @@ async def test_tfloatinst_constructors(connection, expected_tfloatinst):
     [TFloatInst('10.0@2019-09-01 00:00:00+01'), TFloatInst('20.0@2019-09-02 00:00:00+01'),
      TFloatInst('10.0@2019-09-03 00:00:00+01')],
 ])
-async def test_tfloati_constructor(connection, expected_tfloati):
-    if isinstance(expected_tfloati, tuple):
-        params = TFloatI(*expected_tfloati)
+async def test_tfloatinstseq_constructor(connection, expected_tfloatinstset):
+    if isinstance(expected_tfloatinstset, tuple):
+        params = TFloatInstSet(*expected_tfloatinstset)
     else:
-        params = TFloatI(expected_tfloati)
-    await connection.execute('INSERT INTO tbl_tfloati (temp) VALUES ($1)', params)
-    result = await connection.fetchval('SELECT temp FROM tbl_tfloati WHERE temp=$1', params)
-    if isinstance(expected_tfloati, tuple):
-        assert result == TFloatI(*expected_tfloati)
+        params = TFloatInstSet(expected_tfloatinstset)
+    await connection.execute('INSERT INTO tbl_tfloatinstset (temp) VALUES ($1)', params)
+    result = await connection.fetchval('SELECT temp FROM tbl_tfloatinstset WHERE temp=$1', params)
+    if isinstance(expected_tfloatinstset, tuple):
+        assert result == TFloatInstSet(*expected_tfloatinstset)
     else:
-        assert result == TFloatI(expected_tfloati)
+        assert result == TFloatInstSet(expected_tfloatinstset)
 
 @pytest.mark.parametrize('expected_tfloatseq', [
     '[10.0@2019-09-01 00:00:00+01, 20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]',
@@ -61,7 +87,7 @@ async def test_tfloatseq_constructor(connection, expected_tfloatseq):
     else:
         assert result == TFloatSeq(expected_tfloatseq)
 
-@pytest.mark.parametrize('expected_tfloats', [
+@pytest.mark.parametrize('expected_tfloatseqset', [
     '{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}',
     'Interp=Stepwise;{[10.0@2019-09-01 00:00:00+01], [20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]}',
     ['[10.0@2019-09-01 00:00:00+01]', '[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]'],
@@ -75,14 +101,14 @@ async def test_tfloatseq_constructor(connection, expected_tfloatseq):
     ([TFloatSeq('Interp=Stepwise;[10.0@2019-09-01 00:00:00+01]'),
       TFloatSeq('Interp=Stepwise;[20.0@2019-09-02 00:00:00+01, 10.0@2019-09-03 00:00:00+01]')], 'Stepwise'),
 ])
-async def test_tfloats_constructor(connection, expected_tfloats):
-    if isinstance(expected_tfloats, tuple):
-        params = TFloatS(*expected_tfloats)
+async def test_tfloatseqset_constructor(connection, expected_tfloatseqset):
+    if isinstance(expected_tfloatseqset, tuple):
+        params = TFloatSeqSet(*expected_tfloatseqset)
     else:
-        params = TFloatS(expected_tfloats)
-    await connection.execute('INSERT INTO tbl_tfloats (temp) VALUES ($1)', params)
-    result = await connection.fetchval('SELECT temp FROM tbl_tfloats WHERE temp=$1', params)
-    if isinstance(expected_tfloats, tuple):
-        assert result == TFloatS(*expected_tfloats)
+        params = TFloatSeqSet(expected_tfloatseqset)
+    await connection.execute('INSERT INTO tbl_tfloatseqset (temp) VALUES ($1)', params)
+    result = await connection.fetchval('SELECT temp FROM tbl_tfloatseqset WHERE temp=$1', params)
+    if isinstance(expected_tfloatseqset, tuple):
+        assert result == TFloatSeqSet(*expected_tfloatseqset)
     else:
-        assert result == TFloatS(expected_tfloats)
+        assert result == TFloatSeqSet(expected_tfloatseqset)
