@@ -1,7 +1,33 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import pytest
 from dateutil.parser import parse
 from postgis import Point
-from mobilitydb.main import TGeogPointInst, TGeogPointI, TGeogPointSeq, TGeogPointS
+from mobilitydb.main import TGeogPointInst, TGeogPointInstSet, TGeogPointSeq, TGeogPointSeqSet
 
 pytestmark = pytest.mark.asyncio
 
@@ -23,7 +49,7 @@ async def test_tgeogpointinst_constructors(connection, expected_tgeogpointinst):
     result = await connection.fetchval('SELECT temp FROM tbl_tgeogpointinst WHERE temp=$1', params, column=0)
     assert result == TGeogPointInst(expected_tgeogpointinst)
 
-@pytest.mark.parametrize('expected_tgeogpointi', [
+@pytest.mark.parametrize('expected_tgeogpointinstset', [
     '{Point(10.0 10.0)@2019-09-01 00:00:00+01, Point(20.0 20.0)@2019-09-02 00:00:00+01, '
         'Point(10.0 10.0)@2019-09-03 00:00:00+01}',
     'SRID=4326;{Point(10.0 10.0)@2019-09-01 00:00:00+01, Point(20.0 20.0)@2019-09-02 00:00:00+01, '
@@ -49,17 +75,17 @@ async def test_tgeogpointinst_constructors(connection, expected_tgeogpointinst):
         TGeogPointInst('SRID=4326;Point(20.0 20.0)@2019-09-02 00:00:00+01'),
         TGeogPointInst('SRID=4326;Point(10.0 10.0)@2019-09-03 00:00:00+01')],
 ])
-async def test_tgeogpointi_constructor(connection, expected_tgeogpointi):
-    if isinstance(expected_tgeogpointi, tuple):
-        params = TGeogPointI(*expected_tgeogpointi)
+async def test_tgeogpointinstset_constructor(connection, expected_tgeogpointinstset):
+    if isinstance(expected_tgeogpointinstset, tuple):
+        params = TGeogPointInstSet(*expected_tgeogpointinstset)
     else:
-        params = TGeogPointI(expected_tgeogpointi)
-    await connection.execute('INSERT INTO tbl_tgeogpointi (temp) VALUES ($1)', params)
-    result = await connection.fetchval('SELECT temp FROM tbl_tgeogpointi WHERE temp=$1', params)
-    if isinstance(expected_tgeogpointi, tuple):
-        assert result == TGeogPointI(*expected_tgeogpointi)
+        params = TGeogPointInstSet(expected_tgeogpointinstset)
+    await connection.execute('INSERT INTO tbl_tgeogpointinstset (temp) VALUES ($1)', params)
+    result = await connection.fetchval('SELECT temp FROM tbl_tgeogpointinstset WHERE temp=$1', params)
+    if isinstance(expected_tgeogpointinstset, tuple):
+        assert result == TGeogPointInstSet(*expected_tgeogpointinstset)
     else:
-        assert result == TGeogPointI(expected_tgeogpointi)
+        assert result == TGeogPointInstSet(expected_tgeogpointinstset)
 
 @pytest.mark.parametrize('expected_tgeogpointseq', [
     '[Point(10.0 10.0)@2019-09-01 00:00:00+01, Point(20.0 20.0)@2019-09-02 00:00:00+01, '
@@ -105,7 +131,7 @@ async def test_tgeogpointseq_constructor(connection, expected_tgeogpointseq):
     else:
         assert result == TGeogPointSeq(expected_tgeogpointseq)
 
-@pytest.mark.parametrize('expected_tgeogpoints', [
+@pytest.mark.parametrize('expected_tgeogpointseqset', [
     '{[Point(10.0 10.0)@2019-09-01 00:00:00+01], '
         '[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]}',
     'SRID=4326;{[Point(10.0 10.0)@2019-09-01 00:00:00+01], '
@@ -144,14 +170,14 @@ async def test_tgeogpointseq_constructor(connection, expected_tgeogpointseq):
             'Interp=Stepwise;[Point(20.0 20.0)@2019-09-02 00:00:00+01, Point(10.0 10.0)@2019-09-03 00:00:00+01]')],
      'Stepwise'),
 ])
-async def test_tgeogpoints_constructor(connection, expected_tgeogpoints):
-    if isinstance(expected_tgeogpoints, tuple):
-        params = TGeogPointS(*expected_tgeogpoints)
+async def test_tgeogpointseqset_constructor(connection, expected_tgeogpointseqset):
+    if isinstance(expected_tgeogpointseqset, tuple):
+        params = TGeogPointSeqSet(*expected_tgeogpointseqset)
     else:
-        params = TGeogPointS(expected_tgeogpoints)
-    await connection.execute('INSERT INTO tbl_tgeogpoints (temp) VALUES ($1)', params)
-    result = await connection.fetchval('SELECT temp FROM tbl_tgeogpoints WHERE temp=$1', params)
-    if isinstance(expected_tgeogpoints, tuple):
-        assert result == TGeogPointS(*expected_tgeogpoints)
+        params = TGeogPointSeqSet(expected_tgeogpointseqset)
+    await connection.execute('INSERT INTO tbl_tgeogpointseqset (temp) VALUES ($1)', params)
+    result = await connection.fetchval('SELECT temp FROM tbl_tgeogpointseqset WHERE temp=$1', params)
+    if isinstance(expected_tgeogpointseqset, tuple):
+        assert result == TGeogPointSeqSet(*expected_tgeogpointseqset)
     else:
-        assert result == TGeogPointS(expected_tgeogpoints)
+        assert result == TGeogPointSeqSet(expected_tgeogpointseqset)
