@@ -1,3 +1,29 @@
+###############################################################################
+#
+# This MobilityDB code is provided under The PostgreSQL License.
+#
+# Copyright (c) 2019-2021, Université libre de Bruxelles and MobilityDB
+# contributors
+#
+# Permission to use, copy, modify, and distribute this software and its
+# documentation for any purpose, without fee, and without a written 
+# agreement is hereby granted, provided that the above copyright notice and
+# this paragraph and the following two paragraphs appear in all copies.
+#
+# IN NO EVENT SHALL UNIVERSITE LIBRE DE BRUXELLES BE LIABLE TO ANY PARTY FOR
+# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF UNIVERSITE LIBRE DE BRUXELLES HAS BEEN ADVISED OF THE POSSIBILITY 
+# OF SUCH DAMAGE.
+#
+# UNIVERSITE LIBRE DE BRUXELLES SPECIFICALLY DISCLAIMS ANY WARRANTIES, 
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON
+# AN "AS IS" BASIS, AND UNIVERSITE LIBRE DE BRUXELLES HAS NO OBLIGATIONS TO 
+# PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+#
+###############################################################################
+
 import pytest
 from datetime import timedelta
 from dateutil.parser import parse
@@ -27,7 +53,8 @@ def test_timestampset_constructor(cursor, expected_timestampset):
 @pytest.mark.parametrize('expected_timestampset', [
     '{2019-09-01 00:00:00+01, 2019-09-02 00:00:00+01, 2019-09-03 00:00:00+01}',
 ])
-def test_TimestampSet_accessors(cursor, expected_timestampset):
+def test_timestampset_accessors(cursor, expected_timestampset):
+    assert TimestampSet(expected_timestampset).timespan == timedelta(2)
     assert TimestampSet(expected_timestampset).period == Period('[2019-09-01 00:00:00+01, 2019-09-03 00:00:00+01]')
     assert TimestampSet(expected_timestampset).numTimestamps == 3
     assert TimestampSet(expected_timestampset).startTimestamp == parse('2019-09-01 00:00:00+01')
@@ -69,7 +96,7 @@ def test_period_accessors(cursor, expected_period):
     assert Period(expected_period).upper == parse('2019-09-03 00:00:00+01')
     assert Period(expected_period).lower_inc == True
     assert Period(expected_period).upper_inc == True
-    assert Period(expected_period).timespan == timedelta(2)
+    assert Period(expected_period).duration == timedelta(2)
     assert Period(expected_period).shift(timedelta(days=1)) == Period('[2019-09-02 00:00:00+01, 2019-09-04 00:00:00+01]')
 
 @pytest.mark.parametrize('expected_periodset', [
@@ -98,8 +125,9 @@ def test_periodset_constructor(cursor, expected_periodset):
 @pytest.mark.parametrize('expected_periodset', [
     '{[2019-09-01 00:00:00+01, 2019-09-01 00:00:00+01],  [2019-09-02 00:00:00+01, 2019-09-03 00:00:00+01]}',
 ])
-def test_PeriodSet_accessors(cursor, expected_periodset):
-    assert PeriodSet(expected_periodset).timespan == timedelta(1)
+def test_periodset_accessors(cursor, expected_periodset):
+    assert PeriodSet(expected_periodset).duration == timedelta(1)
+    assert PeriodSet(expected_periodset).timespan == timedelta(2)
     assert PeriodSet(expected_periodset).period == Period('[2019-09-01 00:00:00+01, 2019-09-03 00:00:00+01]')
     assert PeriodSet(expected_periodset).numTimestamps == 3
     assert PeriodSet(expected_periodset).startTimestamp == parse('2019-09-01 00:00:00+01')
